module Text.Numerals.Languages.FrenchSpec (
    spec
  ) where

import Data.Text(Text)
import Data.Time.LocalTime(TimeOfDay(TimeOfDay))

import Test.Hspec(Spec)
import Text.Numerals.Languages.French(french)
import Text.Numerals.LanguageTest(testLanguage)

spec :: Spec
spec = testLanguage "French" french (cardinals <> minusCardinals) ordinals shortOrdinals clockTime

cardinals :: [(Integer, Text)]
cardinals = [
    (0, "zéro")
  , (1, "un")
  , (2, "deux")
  , (3, "trois")
  , (4, "quatre")
  , (5, "cinq")
  , (6, "six")
  , (7, "sept")
  , (8, "huit")
  , (9, "neuf")
  , (10, "dix")
  , (11, "onze")
  , (12, "douze")
  , (13, "treize")
  , (14, "quatorze")
  , (15, "quinze")
  , (16, "seize")
  , (17, "dix-sept")
  , (18, "dix-huit")
  , (19, "dix-neuf")
  , (20, "vingt")
  , (21, "vingt et un")
  , (22, "vingt-deux")
  , (23, "vingt-trois")
  , (24, "vingt-quatre")
  , (25, "vingt-cinq")
  , (26, "vingt-six")
  , (27, "vingt-sept")
  , (28, "vingt-huit")
  , (29, "vingt-neuf")
  , (30, "trente")
  , (31, "trente et un")
  , (32, "trente-deux")
  , (33, "trente-trois")
  , (34, "trente-quatre")
  , (35, "trente-cinq")
  , (36, "trente-six")
  , (37, "trente-sept")
  , (38, "trente-huit")
  , (39, "trente-neuf")
  , (40, "quarante")
  , (41, "quarante et un")
  , (42, "quarante-deux")
  , (43, "quarante-trois")
  , (44, "quarante-quatre")
  , (45, "quarante-cinq")
  , (46, "quarante-six")
  , (47, "quarante-sept")
  , (48, "quarante-huit")
  , (49, "quarante-neuf")
  , (50, "cinquante")
  , (51, "cinquante et un")
  , (52, "cinquante-deux")
  , (53, "cinquante-trois")
  , (54, "cinquante-quatre")
  , (55, "cinquante-cinq")
  , (56, "cinquante-six")
  , (57, "cinquante-sept")
  , (58, "cinquante-huit")
  , (59, "cinquante-neuf")
  , (60, "soixante")
  , (61, "soixante et un")
  , (62, "soixante-deux")
  , (63, "soixante-trois")
  , (64, "soixante-quatre")
  , (65, "soixante-cinq")
  , (66, "soixante-six")
  , (67, "soixante-sept")
  , (68, "soixante-huit")
  , (69, "soixante-neuf")
  , (70, "soixante-dix")
  , (71, "soixante et onze")
  , (72, "soixante-douze")
  , (73, "soixante-treize")
  , (74, "soixante-quatorze")
  , (75, "soixante-quinze")
  , (76, "soixante-seize")
  , (77, "soixante-dix-sept")
  , (78, "soixante-dix-huit")
  , (79, "soixante-dix-neuf")
  , (80, "quatre-vingts")
  , (81, "quatre-vingt-un")
  , (82, "quatre-vingt-deux")
  , (83, "quatre-vingt-trois")
  , (84, "quatre-vingt-quatre")
  , (85, "quatre-vingt-cinq")
  , (86, "quatre-vingt-six")
  , (87, "quatre-vingt-sept")
  , (88, "quatre-vingt-huit")
  , (89, "quatre-vingt-neuf")
  , (90, "quatre-vingt-dix")
  , (91, "quatre-vingt-onze")
  , (92, "quatre-vingt-douze")
  , (93, "quatre-vingt-treize")
  , (94, "quatre-vingt-quatorze")
  , (95, "quatre-vingt-quinze")
  , (96, "quatre-vingt-seize")
  , (97, "quatre-vingt-dix-sept")
  , (98, "quatre-vingt-dix-huit")
  , (99, "quatre-vingt-dix-neuf")
  , (100, "cent")
  , (101, "cent un")
  , (102, "cent deux")
  , (103, "cent trois")
  , (104, "cent quatre")
  , (105, "cent cinq")
  , (106, "cent six")
  , (107, "cent sept")
  , (108, "cent huit")
  , (109, "cent neuf")
  , (110, "cent dix")
  , (111, "cent onze")
  , (112, "cent douze")
  , (113, "cent treize")
  , (114, "cent quatorze")
  , (115, "cent quinze")
  , (116, "cent seize")
  , (117, "cent dix-sept")
  , (118, "cent dix-huit")
  , (119, "cent dix-neuf")
  , (120, "cent vingt")
  , (121, "cent vingt et un")
  , (122, "cent vingt-deux")
  , (123, "cent vingt-trois")
  , (124, "cent vingt-quatre")
  , (125, "cent vingt-cinq")
  , (126, "cent vingt-six")
  , (127, "cent vingt-sept")
  , (128, "cent vingt-huit")
  , (129, "cent vingt-neuf")
  , (130, "cent trente")
  , (131, "cent trente et un")
  , (132, "cent trente-deux")
  , (133, "cent trente-trois")
  , (134, "cent trente-quatre")
  , (135, "cent trente-cinq")
  , (136, "cent trente-six")
  , (137, "cent trente-sept")
  , (138, "cent trente-huit")
  , (139, "cent trente-neuf")
  , (140, "cent quarante")
  , (141, "cent quarante et un")
  , (142, "cent quarante-deux")
  , (143, "cent quarante-trois")
  , (144, "cent quarante-quatre")
  , (145, "cent quarante-cinq")
  , (146, "cent quarante-six")
  , (147, "cent quarante-sept")
  , (148, "cent quarante-huit")
  , (149, "cent quarante-neuf")
  , (150, "cent cinquante")
  , (151, "cent cinquante et un")
  , (152, "cent cinquante-deux")
  , (153, "cent cinquante-trois")
  , (154, "cent cinquante-quatre")
  , (155, "cent cinquante-cinq")
  , (156, "cent cinquante-six")
  , (157, "cent cinquante-sept")
  , (158, "cent cinquante-huit")
  , (159, "cent cinquante-neuf")
  , (160, "cent soixante")
  , (161, "cent soixante et un")
  , (162, "cent soixante-deux")
  , (163, "cent soixante-trois")
  , (164, "cent soixante-quatre")
  , (165, "cent soixante-cinq")
  , (166, "cent soixante-six")
  , (167, "cent soixante-sept")
  , (168, "cent soixante-huit")
  , (169, "cent soixante-neuf")
  , (170, "cent soixante-dix")
  , (171, "cent soixante et onze")
  , (172, "cent soixante-douze")
  , (173, "cent soixante-treize")
  , (174, "cent soixante-quatorze")
  , (175, "cent soixante-quinze")
  , (176, "cent soixante-seize")
  , (177, "cent soixante-dix-sept")
  , (178, "cent soixante-dix-huit")
  , (179, "cent soixante-dix-neuf")
  , (180, "cent quatre-vingts")
  , (181, "cent quatre-vingt-un")
  , (182, "cent quatre-vingt-deux")
  , (183, "cent quatre-vingt-trois")
  , (184, "cent quatre-vingt-quatre")
  , (185, "cent quatre-vingt-cinq")
  , (186, "cent quatre-vingt-six")
  , (187, "cent quatre-vingt-sept")
  , (188, "cent quatre-vingt-huit")
  , (189, "cent quatre-vingt-neuf")
  , (190, "cent quatre-vingt-dix")
  , (191, "cent quatre-vingt-onze")
  , (192, "cent quatre-vingt-douze")
  , (193, "cent quatre-vingt-treize")
  , (194, "cent quatre-vingt-quatorze")
  , (195, "cent quatre-vingt-quinze")
  , (196, "cent quatre-vingt-seize")
  , (197, "cent quatre-vingt-dix-sept")
  , (198, "cent quatre-vingt-dix-huit")
  , (199, "cent quatre-vingt-dix-neuf")
  , (200, "deux cents")
  , (233, "deux cent trente-trois")
  , (377, "trois cent soixante-dix-sept")
  , (610, "six cent dix")
  , (987, "neuf cent quatre-vingt-sept")
  , (1597, "mille cinq cent quatre-vingt-dix-sept")
  , (2584, "deux mille cinq cent quatre-vingt-quatre")
  , (4181, "quatre mille cent quatre-vingt-un")
  , (6765, "six mille sept cent soixante-cinq")
  , (10946, "dix mille neuf cent quarante-six")
  , (17711, "dix-sept mille sept cent onze")
  , (28657, "vingt-huit mille six cent cinquante-sept")
  , (46368, "quarante-six mille trois cent soixante-huit")
  , (75025, "soixante-quinze mille vingt-cinq")
  , (121393, "cent vingt et un mille trois cent quatre-vingt-treize")
  , (196418, "cent quatre-vingt-seize mille quatre cent dix-huit")
  , (317811, "trois cent dix-sept mille huit cent onze")
  , (514229, "cinq cent quatorze mille deux cent vingt-neuf")
  , (832040, "huit cent trente-deux mille quarante")
  , (1346269, "un million trois cent quarante-six mille deux cent soixante-neuf")
  , (2178309, "deux millions cent soixante-dix-huit mille trois cent neuf")
  , (3524578, "trois millions cinq cent vingt-quatre mille cinq cent soixante-dix-huit")
  , (5702887, "cinq millions sept cent deux mille huit cent quatre-vingt-sept")
  , (9227465, "neuf millions deux cent vingt-sept mille quatre cent soixante-cinq")
  , (14930352, "quatorze millions neuf cent trente mille trois cent cinquante-deux")
  , (24157817, "vingt-quatre millions cent cinquante-sept mille huit cent dix-sept")
  , (39088169, "trente-neuf millions quatre-vingt-huit mille cent soixante-neuf")
  , (63245986, "soixante-trois millions deux cent quarante-cinq mille neuf cent quatre-vingt-six")
  , (102334155, "cent deux millions trois cent trente-quatre mille cent cinquante-cinq")
  , (165580141, "cent soixante-cinq millions cinq cent quatre-vingt mille cent quarante et un")
  , (267914296, "deux cent soixante-sept millions neuf cent quatorze mille deux cent quatre-vingt-seize")
  , (433494437, "quatre cent trente-trois millions quatre cent quatre-vingt-quatorze mille quatre cent trente-sept")
  , (701408733, "sept cent un millions quatre cent huit mille sept cent trente-trois")
  , (1134903170, "un milliard cent trente-quatre millions neuf cent trois mille cent soixante-dix")
  , (1836311903, "un milliard huit cent trente-six millions trois cent onze mille neuf cent trois")
  , (2971215073, "deux milliards neuf cent soixante et onze millions deux cent quinze mille soixante-treize")
  , (4807526976, "quatre milliards huit cent sept millions cinq cent vingt-six mille neuf cent soixante-seize")
  , (7778742049, "sept milliards sept cent soixante-dix-huit millions sept cent quarante-deux mille quarante-neuf")
  , (12586269025, "douze milliards cinq cent quatre-vingt-six millions deux cent soixante-neuf mille vingt-cinq")
  , (20365011074, "vingt milliards trois cent soixante-cinq millions onze mille soixante-quatorze")
  , (32951280099, "trente-deux milliards neuf cent cinquante et un millions deux cent quatre-vingt mille quatre-vingt-dix-neuf")
  , (53316291173, "cinquante-trois milliards trois cent seize millions deux cent quatre-vingt-onze mille cent soixante-treize")
  , (86267571272, "quatre-vingt-six milliards deux cent soixante-sept millions cinq cent soixante et onze mille deux cent soixante-douze")
  , (139583862445, "cent trente-neuf milliards cinq cent quatre-vingt-trois millions huit cent soixante-deux mille quatre cent quarante-cinq")
  , (225851433717, "deux cent vingt-cinq milliards huit cent cinquante et un millions quatre cent trente-trois mille sept cent dix-sept")
  , (365435296162, "trois cent soixante-cinq milliards quatre cent trente-cinq millions deux cent quatre-vingt-seize mille cent soixante-deux")
  , (591286729879, "cinq cent quatre-vingt-onze milliards deux cent quatre-vingt-six millions sept cent vingt-neuf mille huit cent soixante-dix-neuf")
  , (956722026041, "neuf cent cinquante-six milliards sept cent vingt-deux millions vingt-six mille quarante et un")
  , (1548008755920, "un billion cinq cent quarante-huit milliards huit millions sept cent cinquante-cinq mille neuf cent vingt")
  , (2504730781961, "deux billions cinq cent quatre milliards sept cent trente millions sept cent quatre-vingt-un mille neuf cent soixante et un")
  , (4052739537881, "quatre billions cinquante-deux milliards sept cent trente-neuf millions cinq cent trente-sept mille huit cent quatre-vingt-un")
  , (6557470319842, "six billions cinq cent cinquante-sept milliards quatre cent soixante-dix millions trois cent dix-neuf mille huit cent quarante-deux")
  , (10610209857723, "dix billions six cent dix milliards deux cent neuf millions huit cent cinquante-sept mille sept cent vingt-trois")
  , (17167680177565, "dix-sept billions cent soixante-sept milliards six cent quatre-vingts millions cent soixante-dix-sept mille cinq cent soixante-cinq")
  , (27777890035288, "vingt-sept billions sept cent soixante-dix-sept milliards huit cent quatre-vingt-dix millions trente-cinq mille deux cent quatre-vingt-huit")
  , (44945570212853, "quarante-quatre billions neuf cent quarante-cinq milliards cinq cent soixante-dix millions deux cent douze mille huit cent cinquante-trois")
  , (72723460248141, "soixante-douze billions sept cent vingt-trois milliards quatre cent soixante millions deux cent quarante-huit mille cent quarante et un")
  , (117669030460994, "cent dix-sept billions six cent soixante-neuf milliards trente millions quatre cent soixante mille neuf cent quatre-vingt-quatorze")
  , (190392490709135, "cent quatre-vingt-dix billions trois cent quatre-vingt-douze milliards quatre cent quatre-vingt-dix millions sept cent neuf mille cent trente-cinq")
  , (308061521170129, "trois cent huit billions soixante et un milliards cinq cent vingt et un millions cent soixante-dix mille cent vingt-neuf")
  , (498454011879264, "quatre cent quatre-vingt-dix-huit billions quatre cent cinquante-quatre milliards onze millions huit cent soixante-dix-neuf mille deux cent soixante-quatre")
  , (806515533049393, "huit cent six billions cinq cent quinze milliards cinq cent trente-trois millions quarante-neuf mille trois cent quatre-vingt-treize")
  , (1304969544928657, "un billiard trois cent quatre billions neuf cent soixante-neuf milliards cinq cent quarante-quatre millions neuf cent vingt-huit mille six cent cinquante-sept")
  , (2111485077978050, "deux billiards cent onze billions quatre cent quatre-vingt-cinq milliards soixante-dix-sept millions neuf cent soixante-dix-huit mille cinquante")
  , (3416454622906707, "trois billiards quatre cent seize billions quatre cent cinquante-quatre milliards six cent vingt-deux millions neuf cent six mille sept cent sept")
  , (5527939700884757, "cinq billiards cinq cent vingt-sept billions neuf cent trente-neuf milliards sept cents millions huit cent quatre-vingt-quatre mille sept cent cinquante-sept")
  , (8944394323791464, "huit billiards neuf cent quarante-quatre billions trois cent quatre-vingt-quatorze milliards trois cent vingt-trois millions sept cent quatre-vingt-onze mille quatre cent soixante-quatre")
  , (14472334024676221, "quatorze billiards quatre cent soixante-douze billions trois cent trente-quatre milliards vingt-quatre millions six cent soixante-seize mille deux cent vingt et un")
  , (23416728348467685, "vingt-trois billiards quatre cent seize billions sept cent vingt-huit milliards trois cent quarante-huit millions quatre cent soixante-sept mille six cent quatre-vingt-cinq")
  , (37889062373143906, "trente-sept billiards huit cent quatre-vingt-neuf billions soixante-deux milliards trois cent soixante-treize millions cent quarante-trois mille neuf cent six")
  , (61305790721611591, "soixante et un billiards trois cent cinq billions sept cent quatre-vingt-dix milliards sept cent vingt et un millions six cent onze mille cinq cent quatre-vingt-onze")
  , (99194853094755497, "quatre-vingt-dix-neuf billiards cent quatre-vingt-quatorze billions huit cent cinquante-trois milliards quatre-vingt-quatorze millions sept cent cinquante-cinq mille quatre cent quatre-vingt-dix-sept")
  , (160500643816367088, "cent soixante billiards cinq cents billions six cent quarante-trois milliards huit cent seize millions trois cent soixante-sept mille quatre-vingt-huit")
  , (259695496911122585, "deux cent cinquante-neuf billiards six cent quatre-vingt-quinze billions quatre cent quatre-vingt-seize milliards neuf cent onze millions cent vingt-deux mille cinq cent quatre-vingt-cinq")
  , (420196140727489673, "quatre cent vingt billiards cent quatre-vingt-seize billions cent quarante milliards sept cent vingt-sept millions quatre cent quatre-vingt-neuf mille six cent soixante-treize")
  , (679891637638612258, "six cent soixante-dix-neuf billiards huit cent quatre-vingt-onze billions six cent trente-sept milliards six cent trente-huit millions six cent douze mille deux cent cinquante-huit")
  , (1100087778366101931, "un trillion cent billiards quatre-vingt-sept billions sept cent soixante-dix-huit milliards trois cent soixante-six millions cent un mille neuf cent trente et un")
  , (1779979416004714189, "un trillion sept cent soixante-dix-neuf billiards neuf cent soixante-dix-neuf billions quatre cent seize milliards quatre millions sept cent quatorze mille cent quatre-vingt-neuf")
  , (2880067194370816120, "deux trillions huit cent quatre-vingts billiards soixante-sept billions cent quatre-vingt-quatorze milliards trois cent soixante-dix millions huit cent seize mille cent vingt")
  , (4660046610375530309, "quatre trillions six cent soixante billiards quarante-six billions six cent dix milliards trois cent soixante-quinze millions cinq cent trente mille trois cent neuf")
  , (7540113804746346429, "sept trillions cinq cent quarante billiards cent treize billions huit cent quatre milliards sept cent quarante-six millions trois cent quarante-six mille quatre cent vingt-neuf")
  , (12200160415121876738, "douze trillions deux cents billiards cent soixante billions quatre cent quinze milliards cent vingt et un millions huit cent soixante-seize mille sept cent trente-huit")
  , (19740274219868223167, "dix-neuf trillions sept cent quarante billiards deux cent soixante-quatorze billions deux cent dix-neuf milliards huit cent soixante-huit millions deux cent vingt-trois mille cent soixante-sept")
  , (31940434634990099905, "trente et un trillions neuf cent quarante billiards quatre cent trente-quatre billions six cent trente-quatre milliards neuf cent quatre-vingt-dix millions quatre-vingt-dix-neuf mille neuf cent cinq")
  , (51680708854858323072, "cinquante et un trillions six cent quatre-vingts billiards sept cent huit billions huit cent cinquante-quatre milliards huit cent cinquante-huit millions trois cent vingt-trois mille soixante-douze")
  , (83621143489848422977, "quatre-vingt-trois trillions six cent vingt et un billiards cent quarante-trois billions quatre cent quatre-vingt-neuf milliards huit cent quarante-huit millions quatre cent vingt-deux mille neuf cent soixante-dix-sept")
  , (135301852344706746049, "cent trente-cinq trillions trois cent un billiards huit cent cinquante-deux billions trois cent quarante-quatre milliards sept cent six millions sept cent quarante-six mille quarante-neuf")
  , (218922995834555169026, "deux cent dix-huit trillions neuf cent vingt-deux billiards neuf cent quatre-vingt-quinze billions huit cent trente-quatre milliards cinq cent cinquante-cinq millions cent soixante-neuf mille vingt-six")
  , (354224848179261915075, "trois cent cinquante-quatre trillions deux cent vingt-quatre billiards huit cent quarante-huit billions cent soixante-dix-neuf milliards deux cent soixante et un millions neuf cent quinze mille soixante-quinze")
  , (573147844013817084101, "cinq cent soixante-treize trillions cent quarante-sept billiards huit cent quarante-quatre billions treize milliards huit cent dix-sept millions quatre-vingt-quatre mille cent un")
  , (927372692193078999176, "neuf cent vingt-sept trillions trois cent soixante-douze billiards six cent quatre-vingt-douze billions cent quatre-vingt-treize milliards soixante-dix-huit millions neuf cent quatre-vingt-dix-neuf mille cent soixante-seize")
  , (1500520536206896083277, "un trilliard cinq cents trillions cinq cent vingt billiards cinq cent trente-six billions deux cent six milliards huit cent quatre-vingt-seize millions quatre-vingt-trois mille deux cent soixante-dix-sept")
  , (2427893228399975082453, "deux trilliards quatre cent vingt-sept trillions huit cent quatre-vingt-treize billiards deux cent vingt-huit billions trois cent quatre-vingt-dix-neuf milliards neuf cent soixante-quinze millions quatre-vingt-deux mille quatre cent cinquante-trois")
  , (3928413764606871165730, "trois trilliards neuf cent vingt-huit trillions quatre cent treize billiards sept cent soixante-quatre billions six cent six milliards huit cent soixante et onze millions cent soixante-cinq mille sept cent trente")
  , (6356306993006846248183, "six trilliards trois cent cinquante-six trillions trois cent six billiards neuf cent quatre-vingt-treize billions six milliards huit cent quarante-six millions deux cent quarante-huit mille cent quatre-vingt-trois")
  , (10284720757613717413913, "dix trilliards deux cent quatre-vingt-quatre trillions sept cent vingt billiards sept cent cinquante-sept billions six cent treize milliards sept cent dix-sept millions quatre cent treize mille neuf cent treize")
  , (16641027750620563662096, "seize trilliards six cent quarante et un trillions vingt-sept billiards sept cent cinquante billions six cent vingt milliards cinq cent soixante-trois millions six cent soixante-deux mille quatre-vingt-seize")
  , (26925748508234281076009, "vingt-six trilliards neuf cent vingt-cinq trillions sept cent quarante-huit billiards cinq cent huit billions deux cent trente-quatre milliards deux cent quatre-vingt-un millions soixante-seize mille neuf")
  , (43566776258854844738105, "quarante-trois trilliards cinq cent soixante-six trillions sept cent soixante-seize billiards deux cent cinquante-huit billions huit cent cinquante-quatre milliards huit cent quarante-quatre millions sept cent trente-huit mille cent cinq")
  , (70492524767089125814114, "soixante-dix trilliards quatre cent quatre-vingt-douze trillions cinq cent vingt-quatre billiards sept cent soixante-sept billions quatre-vingt-neuf milliards cent vingt-cinq millions huit cent quatorze mille cent quatorze")
  , (114059301025943970552219, "cent quatorze trilliards cinquante-neuf trillions trois cent un billiards vingt-cinq billions neuf cent quarante-trois milliards neuf cent soixante-dix millions cinq cent cinquante-deux mille deux cent dix-neuf")
  , (1000, "mille")
  , (10000, "dix mille")
  , (100000, "cent mille")
  , (1000000, "un million")
  , (10000000, "dix millions")
  , (100000000, "cent millions")
  , (1000000000, "un milliard")
  , (10000000000, "dix milliards")
  , (100000000000, "cent milliards")
  , (1000000000000, "un billion")
  , (10000000000000, "dix billions")
  , (100000000000000, "cent billions")
  , (1000000000000000, "un billiard")
  , (10000000000000000, "dix billiards")
  , (100000000000000000, "cent billiards")
  , (1000000000000000000, "un trillion")
  , (10000000000000000000, "dix trillions")
  , (100000000000000000000, "cent trillions")
  , (1000000000000000000000, "un trilliard")
  , (10000000000000000000000, "dix trilliards")
  , (100000000000000000000000, "cent trilliards")
  , (1000000000000000000000000, "un quadrillion")
  ]

minusCardinals :: [(Integer, Text)]
minusCardinals = [
    (0, "zéro")
  , (-1, "moins un")
  , (-2, "moins deux")
  , (-3, "moins trois")
  , (-4, "moins quatre")
  , (-5, "moins cinq")
  , (-6, "moins six")
  , (-7, "moins sept")
  , (-8, "moins huit")
  , (-9, "moins neuf")
  , (-10, "moins dix")
  , (-11, "moins onze")
  , (-12, "moins douze")
  , (-13, "moins treize")
  , (-14, "moins quatorze")
  , (-15, "moins quinze")
  , (-16, "moins seize")
  , (-17, "moins dix-sept")
  , (-18, "moins dix-huit")
  , (-19, "moins dix-neuf")
  , (-20, "moins vingt")
  , (-21, "moins vingt et un")
  , (-22, "moins vingt-deux")
  , (-23, "moins vingt-trois")
  , (-24, "moins vingt-quatre")
  , (-25, "moins vingt-cinq")
  , (-26, "moins vingt-six")
  , (-27, "moins vingt-sept")
  , (-28, "moins vingt-huit")
  , (-29, "moins vingt-neuf")
  , (-30, "moins trente")
  , (-31, "moins trente et un")
  , (-32, "moins trente-deux")
  , (-33, "moins trente-trois")
  , (-34, "moins trente-quatre")
  , (-35, "moins trente-cinq")
  , (-36, "moins trente-six")
  , (-37, "moins trente-sept")
  , (-38, "moins trente-huit")
  , (-39, "moins trente-neuf")
  , (-40, "moins quarante")
  , (-41, "moins quarante et un")
  , (-42, "moins quarante-deux")
  , (-43, "moins quarante-trois")
  , (-44, "moins quarante-quatre")
  , (-45, "moins quarante-cinq")
  , (-46, "moins quarante-six")
  , (-47, "moins quarante-sept")
  , (-48, "moins quarante-huit")
  , (-49, "moins quarante-neuf")
  , (-50, "moins cinquante")
  , (-51, "moins cinquante et un")
  , (-52, "moins cinquante-deux")
  , (-53, "moins cinquante-trois")
  , (-54, "moins cinquante-quatre")
  , (-55, "moins cinquante-cinq")
  , (-56, "moins cinquante-six")
  , (-57, "moins cinquante-sept")
  , (-58, "moins cinquante-huit")
  , (-59, "moins cinquante-neuf")
  , (-60, "moins soixante")
  , (-61, "moins soixante et un")
  , (-62, "moins soixante-deux")
  , (-63, "moins soixante-trois")
  , (-64, "moins soixante-quatre")
  , (-65, "moins soixante-cinq")
  , (-66, "moins soixante-six")
  , (-67, "moins soixante-sept")
  , (-68, "moins soixante-huit")
  , (-69, "moins soixante-neuf")
  , (-70, "moins soixante-dix")
  , (-71, "moins soixante et onze")
  , (-72, "moins soixante-douze")
  , (-73, "moins soixante-treize")
  , (-74, "moins soixante-quatorze")
  , (-75, "moins soixante-quinze")
  , (-76, "moins soixante-seize")
  , (-77, "moins soixante-dix-sept")
  , (-78, "moins soixante-dix-huit")
  , (-79, "moins soixante-dix-neuf")
  , (-80, "moins quatre-vingts")
  , (-81, "moins quatre-vingt-un")
  , (-82, "moins quatre-vingt-deux")
  , (-83, "moins quatre-vingt-trois")
  , (-84, "moins quatre-vingt-quatre")
  , (-85, "moins quatre-vingt-cinq")
  , (-86, "moins quatre-vingt-six")
  , (-87, "moins quatre-vingt-sept")
  , (-88, "moins quatre-vingt-huit")
  , (-89, "moins quatre-vingt-neuf")
  , (-90, "moins quatre-vingt-dix")
  , (-91, "moins quatre-vingt-onze")
  , (-92, "moins quatre-vingt-douze")
  , (-93, "moins quatre-vingt-treize")
  , (-94, "moins quatre-vingt-quatorze")
  , (-95, "moins quatre-vingt-quinze")
  , (-96, "moins quatre-vingt-seize")
  , (-97, "moins quatre-vingt-dix-sept")
  , (-98, "moins quatre-vingt-dix-huit")
  , (-99, "moins quatre-vingt-dix-neuf")
  , (-100, "moins cent")
  , (-101, "moins cent un")
  , (-102, "moins cent deux")
  , (-103, "moins cent trois")
  , (-104, "moins cent quatre")
  , (-105, "moins cent cinq")
  , (-106, "moins cent six")
  , (-107, "moins cent sept")
  , (-108, "moins cent huit")
  , (-109, "moins cent neuf")
  , (-110, "moins cent dix")
  , (-111, "moins cent onze")
  , (-112, "moins cent douze")
  , (-113, "moins cent treize")
  , (-114, "moins cent quatorze")
  , (-115, "moins cent quinze")
  , (-116, "moins cent seize")
  , (-117, "moins cent dix-sept")
  , (-118, "moins cent dix-huit")
  , (-119, "moins cent dix-neuf")
  , (-120, "moins cent vingt")
  , (-121, "moins cent vingt et un")
  , (-122, "moins cent vingt-deux")
  , (-123, "moins cent vingt-trois")
  , (-124, "moins cent vingt-quatre")
  , (-125, "moins cent vingt-cinq")
  , (-126, "moins cent vingt-six")
  , (-127, "moins cent vingt-sept")
  , (-128, "moins cent vingt-huit")
  , (-129, "moins cent vingt-neuf")
  , (-130, "moins cent trente")
  , (-131, "moins cent trente et un")
  , (-132, "moins cent trente-deux")
  , (-133, "moins cent trente-trois")
  , (-134, "moins cent trente-quatre")
  , (-135, "moins cent trente-cinq")
  , (-136, "moins cent trente-six")
  , (-137, "moins cent trente-sept")
  , (-138, "moins cent trente-huit")
  , (-139, "moins cent trente-neuf")
  , (-140, "moins cent quarante")
  , (-141, "moins cent quarante et un")
  , (-142, "moins cent quarante-deux")
  , (-143, "moins cent quarante-trois")
  , (-144, "moins cent quarante-quatre")
  , (-145, "moins cent quarante-cinq")
  , (-146, "moins cent quarante-six")
  , (-147, "moins cent quarante-sept")
  , (-148, "moins cent quarante-huit")
  , (-149, "moins cent quarante-neuf")
  , (-150, "moins cent cinquante")
  , (-151, "moins cent cinquante et un")
  , (-152, "moins cent cinquante-deux")
  , (-153, "moins cent cinquante-trois")
  , (-154, "moins cent cinquante-quatre")
  , (-155, "moins cent cinquante-cinq")
  , (-156, "moins cent cinquante-six")
  , (-157, "moins cent cinquante-sept")
  , (-158, "moins cent cinquante-huit")
  , (-159, "moins cent cinquante-neuf")
  , (-160, "moins cent soixante")
  , (-161, "moins cent soixante et un")
  , (-162, "moins cent soixante-deux")
  , (-163, "moins cent soixante-trois")
  , (-164, "moins cent soixante-quatre")
  , (-165, "moins cent soixante-cinq")
  , (-166, "moins cent soixante-six")
  , (-167, "moins cent soixante-sept")
  , (-168, "moins cent soixante-huit")
  , (-169, "moins cent soixante-neuf")
  , (-170, "moins cent soixante-dix")
  , (-171, "moins cent soixante et onze")
  , (-172, "moins cent soixante-douze")
  , (-173, "moins cent soixante-treize")
  , (-174, "moins cent soixante-quatorze")
  , (-175, "moins cent soixante-quinze")
  , (-176, "moins cent soixante-seize")
  , (-177, "moins cent soixante-dix-sept")
  , (-178, "moins cent soixante-dix-huit")
  , (-179, "moins cent soixante-dix-neuf")
  , (-180, "moins cent quatre-vingts")
  , (-181, "moins cent quatre-vingt-un")
  , (-182, "moins cent quatre-vingt-deux")
  , (-183, "moins cent quatre-vingt-trois")
  , (-184, "moins cent quatre-vingt-quatre")
  , (-185, "moins cent quatre-vingt-cinq")
  , (-186, "moins cent quatre-vingt-six")
  , (-187, "moins cent quatre-vingt-sept")
  , (-188, "moins cent quatre-vingt-huit")
  , (-189, "moins cent quatre-vingt-neuf")
  , (-190, "moins cent quatre-vingt-dix")
  , (-191, "moins cent quatre-vingt-onze")
  , (-192, "moins cent quatre-vingt-douze")
  , (-193, "moins cent quatre-vingt-treize")
  , (-194, "moins cent quatre-vingt-quatorze")
  , (-195, "moins cent quatre-vingt-quinze")
  , (-196, "moins cent quatre-vingt-seize")
  , (-197, "moins cent quatre-vingt-dix-sept")
  , (-198, "moins cent quatre-vingt-dix-huit")
  , (-199, "moins cent quatre-vingt-dix-neuf")
  , (-200, "moins deux cents")
  ]

ordinals :: [(Integer, Text)]
ordinals = [
    (0, "zéroième")
  , (1, "premier")
  , (2, "deuxième")
  , (3, "troisième")
  , (4, "quatrième")
  , (5, "cinquième")
  , (6, "sixième")
  , (7, "septième")
  , (8, "huitième")
  , (9, "neuvième")
  , (10, "dixième")
  , (11, "onzième")
  , (12, "douzième")
  , (13, "treizième")
  , (14, "quatorzième")
  , (15, "quinzième")
  , (16, "seizième")
  , (17, "dix-septième")
  , (18, "dix-huitième")
  , (19, "dix-neuvième")
  , (20, "vingtième")
  , (21, "vingt et unième")
  , (22, "vingt-deuxième")
  , (23, "vingt-troisième")
  , (24, "vingt-quatrième")
  , (25, "vingt-cinquième")
  , (26, "vingt-sixième")
  , (27, "vingt-septième")
  , (28, "vingt-huitième")
  , (29, "vingt-neuvième")
  , (30, "trentième")
  , (31, "trente et unième")
  , (32, "trente-deuxième")
  , (33, "trente-troisième")
  , (34, "trente-quatrième")
  , (35, "trente-cinquième")
  , (36, "trente-sixième")
  , (37, "trente-septième")
  , (38, "trente-huitième")
  , (39, "trente-neuvième")
  , (40, "quarantième")
  , (41, "quarante et unième")
  , (42, "quarante-deuxième")
  , (43, "quarante-troisième")
  , (44, "quarante-quatrième")
  , (45, "quarante-cinquième")
  , (46, "quarante-sixième")
  , (47, "quarante-septième")
  , (48, "quarante-huitième")
  , (49, "quarante-neuvième")
  , (50, "cinquantième")
  , (51, "cinquante et unième")
  , (52, "cinquante-deuxième")
  , (53, "cinquante-troisième")
  , (54, "cinquante-quatrième")
  , (55, "cinquante-cinquième")
  , (56, "cinquante-sixième")
  , (57, "cinquante-septième")
  , (58, "cinquante-huitième")
  , (59, "cinquante-neuvième")
  , (60, "soixantième")
  , (61, "soixante et unième")
  , (62, "soixante-deuxième")
  , (63, "soixante-troisième")
  , (64, "soixante-quatrième")
  , (65, "soixante-cinquième")
  , (66, "soixante-sixième")
  , (67, "soixante-septième")
  , (68, "soixante-huitième")
  , (69, "soixante-neuvième")
  , (70, "soixante-dixième")
  , (71, "soixante et onzième")
  , (72, "soixante-douzième")
  , (73, "soixante-treizième")
  , (74, "soixante-quatorzième")
  , (75, "soixante-quinzième")
  , (76, "soixante-seizième")
  , (77, "soixante-dix-septième")
  , (78, "soixante-dix-huitième")
  , (79, "soixante-dix-neuvième")
  , (80, "quatre-vingtsième")
  , (81, "quatre-vingt-unième")
  , (82, "quatre-vingt-deuxième")
  , (83, "quatre-vingt-troisième")
  , (84, "quatre-vingt-quatrième")
  , (85, "quatre-vingt-cinquième")
  , (86, "quatre-vingt-sixième")
  , (87, "quatre-vingt-septième")
  , (88, "quatre-vingt-huitième")
  , (89, "quatre-vingt-neuvième")
  , (90, "quatre-vingt-dixième")
  , (91, "quatre-vingt-onzième")
  , (92, "quatre-vingt-douzième")
  , (93, "quatre-vingt-treizième")
  , (94, "quatre-vingt-quatorzième")
  , (95, "quatre-vingt-quinzième")
  , (96, "quatre-vingt-seizième")
  , (97, "quatre-vingt-dix-septième")
  , (98, "quatre-vingt-dix-huitième")
  , (99, "quatre-vingt-dix-neuvième")
  , (100, "centième")
  , (101, "cent unième")
  , (102, "cent deuxième")
  , (103, "cent troisième")
  , (104, "cent quatrième")
  , (105, "cent cinquième")
  , (106, "cent sixième")
  , (107, "cent septième")
  , (108, "cent huitième")
  , (109, "cent neuvième")
  , (110, "cent dixième")
  , (111, "cent onzième")
  , (112, "cent douzième")
  , (113, "cent treizième")
  , (114, "cent quatorzième")
  , (115, "cent quinzième")
  , (116, "cent seizième")
  , (117, "cent dix-septième")
  , (118, "cent dix-huitième")
  , (119, "cent dix-neuvième")
  , (120, "cent vingtième")
  , (121, "cent vingt et unième")
  , (122, "cent vingt-deuxième")
  , (123, "cent vingt-troisième")
  , (124, "cent vingt-quatrième")
  , (125, "cent vingt-cinquième")
  , (126, "cent vingt-sixième")
  , (127, "cent vingt-septième")
  , (128, "cent vingt-huitième")
  , (129, "cent vingt-neuvième")
  , (130, "cent trentième")
  , (131, "cent trente et unième")
  , (132, "cent trente-deuxième")
  , (133, "cent trente-troisième")
  , (134, "cent trente-quatrième")
  , (135, "cent trente-cinquième")
  , (136, "cent trente-sixième")
  , (137, "cent trente-septième")
  , (138, "cent trente-huitième")
  , (139, "cent trente-neuvième")
  , (140, "cent quarantième")
  , (141, "cent quarante et unième")
  , (142, "cent quarante-deuxième")
  , (143, "cent quarante-troisième")
  , (144, "cent quarante-quatrième")
  , (145, "cent quarante-cinquième")
  , (146, "cent quarante-sixième")
  , (147, "cent quarante-septième")
  , (148, "cent quarante-huitième")
  , (149, "cent quarante-neuvième")
  , (150, "cent cinquantième")
  , (151, "cent cinquante et unième")
  , (152, "cent cinquante-deuxième")
  , (153, "cent cinquante-troisième")
  , (154, "cent cinquante-quatrième")
  , (155, "cent cinquante-cinquième")
  , (156, "cent cinquante-sixième")
  , (157, "cent cinquante-septième")
  , (158, "cent cinquante-huitième")
  , (159, "cent cinquante-neuvième")
  , (160, "cent soixantième")
  , (161, "cent soixante et unième")
  , (162, "cent soixante-deuxième")
  , (163, "cent soixante-troisième")
  , (164, "cent soixante-quatrième")
  , (165, "cent soixante-cinquième")
  , (166, "cent soixante-sixième")
  , (167, "cent soixante-septième")
  , (168, "cent soixante-huitième")
  , (169, "cent soixante-neuvième")
  , (170, "cent soixante-dixième")
  , (171, "cent soixante et onzième")
  , (172, "cent soixante-douzième")
  , (173, "cent soixante-treizième")
  , (174, "cent soixante-quatorzième")
  , (175, "cent soixante-quinzième")
  , (176, "cent soixante-seizième")
  , (177, "cent soixante-dix-septième")
  , (178, "cent soixante-dix-huitième")
  , (179, "cent soixante-dix-neuvième")
  , (180, "cent quatre-vingtsième")
  , (181, "cent quatre-vingt-unième")
  , (182, "cent quatre-vingt-deuxième")
  , (183, "cent quatre-vingt-troisième")
  , (184, "cent quatre-vingt-quatrième")
  , (185, "cent quatre-vingt-cinquième")
  , (186, "cent quatre-vingt-sixième")
  , (187, "cent quatre-vingt-septième")
  , (188, "cent quatre-vingt-huitième")
  , (189, "cent quatre-vingt-neuvième")
  , (190, "cent quatre-vingt-dixième")
  , (191, "cent quatre-vingt-onzième")
  , (192, "cent quatre-vingt-douzième")
  , (193, "cent quatre-vingt-treizième")
  , (194, "cent quatre-vingt-quatorzième")
  , (195, "cent quatre-vingt-quinzième")
  , (196, "cent quatre-vingt-seizième")
  , (197, "cent quatre-vingt-dix-septième")
  , (198, "cent quatre-vingt-dix-huitième")
  , (199, "cent quatre-vingt-dix-neuvième")
  , (200, "deux centsième")
  , (233, "deux cent trente-troisième")
  , (377, "trois cent soixante-dix-septième")
  , (610, "six cent dixième")
  , (987, "neuf cent quatre-vingt-septième")
  , (1597, "mille cinq cent quatre-vingt-dix-septième")
  , (2584, "deux mille cinq cent quatre-vingt-quatrième")
  , (4181, "quatre mille cent quatre-vingt-unième")
  , (6765, "six mille sept cent soixante-cinquième")
  , (10946, "dix mille neuf cent quarante-sixième")
  , (17711, "dix-sept mille sept cent onzième")
  , (28657, "vingt-huit mille six cent cinquante-septième")
  , (46368, "quarante-six mille trois cent soixante-huitième")
  , (75025, "soixante-quinze mille vingt-cinquième")
  , (121393, "cent vingt et un mille trois cent quatre-vingt-treizième")
  , (196418, "cent quatre-vingt-seize mille quatre cent dix-huitième")
  , (317811, "trois cent dix-sept mille huit cent onzième")
  , (514229, "cinq cent quatorze mille deux cent vingt-neuvième")
  , (832040, "huit cent trente-deux mille quarantième")
  , (1346269, "un million trois cent quarante-six mille deux cent soixante-neuvième")
  , (2178309, "deux millions cent soixante-dix-huit mille trois cent neuvième")
  , (3524578, "trois millions cinq cent vingt-quatre mille cinq cent soixante-dix-huitième")
  , (5702887, "cinq millions sept cent deux mille huit cent quatre-vingt-septième")
  , (9227465, "neuf millions deux cent vingt-sept mille quatre cent soixante-cinquième")
  , (14930352, "quatorze millions neuf cent trente mille trois cent cinquante-deuxième")
  , (24157817, "vingt-quatre millions cent cinquante-sept mille huit cent dix-septième")
  , (39088169, "trente-neuf millions quatre-vingt-huit mille cent soixante-neuvième")
  , (63245986, "soixante-trois millions deux cent quarante-cinq mille neuf cent quatre-vingt-sixième")
  , (102334155, "cent deux millions trois cent trente-quatre mille cent cinquante-cinquième")
  , (165580141, "cent soixante-cinq millions cinq cent quatre-vingt mille cent quarante et unième")
  , (267914296, "deux cent soixante-sept millions neuf cent quatorze mille deux cent quatre-vingt-seizième")
  , (433494437, "quatre cent trente-trois millions quatre cent quatre-vingt-quatorze mille quatre cent trente-septième")
  , (701408733, "sept cent un millions quatre cent huit mille sept cent trente-troisième")
  , (1134903170, "un milliard cent trente-quatre millions neuf cent trois mille cent soixante-dixième")
  , (1836311903, "un milliard huit cent trente-six millions trois cent onze mille neuf cent troisième")
  , (2971215073, "deux milliards neuf cent soixante et onze millions deux cent quinze mille soixante-treizième")
  , (4807526976, "quatre milliards huit cent sept millions cinq cent vingt-six mille neuf cent soixante-seizième")
  , (7778742049, "sept milliards sept cent soixante-dix-huit millions sept cent quarante-deux mille quarante-neuvième")
  , (12586269025, "douze milliards cinq cent quatre-vingt-six millions deux cent soixante-neuf mille vingt-cinquième")
  , (20365011074, "vingt milliards trois cent soixante-cinq millions onze mille soixante-quatorzième")
  , (32951280099, "trente-deux milliards neuf cent cinquante et un millions deux cent quatre-vingt mille quatre-vingt-dix-neuvième")
  , (53316291173, "cinquante-trois milliards trois cent seize millions deux cent quatre-vingt-onze mille cent soixante-treizième")
  , (86267571272, "quatre-vingt-six milliards deux cent soixante-sept millions cinq cent soixante et onze mille deux cent soixante-douzième")
  , (139583862445, "cent trente-neuf milliards cinq cent quatre-vingt-trois millions huit cent soixante-deux mille quatre cent quarante-cinquième")
  , (225851433717, "deux cent vingt-cinq milliards huit cent cinquante et un millions quatre cent trente-trois mille sept cent dix-septième")
  , (365435296162, "trois cent soixante-cinq milliards quatre cent trente-cinq millions deux cent quatre-vingt-seize mille cent soixante-deuxième")
  , (591286729879, "cinq cent quatre-vingt-onze milliards deux cent quatre-vingt-six millions sept cent vingt-neuf mille huit cent soixante-dix-neuvième")
  , (956722026041, "neuf cent cinquante-six milliards sept cent vingt-deux millions vingt-six mille quarante et unième")
  , (1548008755920, "un billion cinq cent quarante-huit milliards huit millions sept cent cinquante-cinq mille neuf cent vingtième")
  , (2504730781961, "deux billions cinq cent quatre milliards sept cent trente millions sept cent quatre-vingt-un mille neuf cent soixante et unième")
  , (4052739537881, "quatre billions cinquante-deux milliards sept cent trente-neuf millions cinq cent trente-sept mille huit cent quatre-vingt-unième")
  , (6557470319842, "six billions cinq cent cinquante-sept milliards quatre cent soixante-dix millions trois cent dix-neuf mille huit cent quarante-deuxième")
  , (10610209857723, "dix billions six cent dix milliards deux cent neuf millions huit cent cinquante-sept mille sept cent vingt-troisième")
  , (17167680177565, "dix-sept billions cent soixante-sept milliards six cent quatre-vingts millions cent soixante-dix-sept mille cinq cent soixante-cinquième")
  , (27777890035288, "vingt-sept billions sept cent soixante-dix-sept milliards huit cent quatre-vingt-dix millions trente-cinq mille deux cent quatre-vingt-huitième")
  , (44945570212853, "quarante-quatre billions neuf cent quarante-cinq milliards cinq cent soixante-dix millions deux cent douze mille huit cent cinquante-troisième")
  , (72723460248141, "soixante-douze billions sept cent vingt-trois milliards quatre cent soixante millions deux cent quarante-huit mille cent quarante et unième")
  , (117669030460994, "cent dix-sept billions six cent soixante-neuf milliards trente millions quatre cent soixante mille neuf cent quatre-vingt-quatorzième")
  , (190392490709135, "cent quatre-vingt-dix billions trois cent quatre-vingt-douze milliards quatre cent quatre-vingt-dix millions sept cent neuf mille cent trente-cinquième")
  , (308061521170129, "trois cent huit billions soixante et un milliards cinq cent vingt et un millions cent soixante-dix mille cent vingt-neuvième")
  , (498454011879264, "quatre cent quatre-vingt-dix-huit billions quatre cent cinquante-quatre milliards onze millions huit cent soixante-dix-neuf mille deux cent soixante-quatrième")
  , (806515533049393, "huit cent six billions cinq cent quinze milliards cinq cent trente-trois millions quarante-neuf mille trois cent quatre-vingt-treizième")
  , (1304969544928657, "un billiard trois cent quatre billions neuf cent soixante-neuf milliards cinq cent quarante-quatre millions neuf cent vingt-huit mille six cent cinquante-septième")
  , (2111485077978050, "deux billiards cent onze billions quatre cent quatre-vingt-cinq milliards soixante-dix-sept millions neuf cent soixante-dix-huit mille cinquantième")
  , (3416454622906707, "trois billiards quatre cent seize billions quatre cent cinquante-quatre milliards six cent vingt-deux millions neuf cent six mille sept cent septième")
  , (5527939700884757, "cinq billiards cinq cent vingt-sept billions neuf cent trente-neuf milliards sept cents millions huit cent quatre-vingt-quatre mille sept cent cinquante-septième")
  , (8944394323791464, "huit billiards neuf cent quarante-quatre billions trois cent quatre-vingt-quatorze milliards trois cent vingt-trois millions sept cent quatre-vingt-onze mille quatre cent soixante-quatrième")
  , (14472334024676221, "quatorze billiards quatre cent soixante-douze billions trois cent trente-quatre milliards vingt-quatre millions six cent soixante-seize mille deux cent vingt et unième")
  , (23416728348467685, "vingt-trois billiards quatre cent seize billions sept cent vingt-huit milliards trois cent quarante-huit millions quatre cent soixante-sept mille six cent quatre-vingt-cinquième")
  , (37889062373143906, "trente-sept billiards huit cent quatre-vingt-neuf billions soixante-deux milliards trois cent soixante-treize millions cent quarante-trois mille neuf cent sixième")
  , (61305790721611591, "soixante et un billiards trois cent cinq billions sept cent quatre-vingt-dix milliards sept cent vingt et un millions six cent onze mille cinq cent quatre-vingt-onzième")
  , (99194853094755497, "quatre-vingt-dix-neuf billiards cent quatre-vingt-quatorze billions huit cent cinquante-trois milliards quatre-vingt-quatorze millions sept cent cinquante-cinq mille quatre cent quatre-vingt-dix-septième")
  , (160500643816367088, "cent soixante billiards cinq cents billions six cent quarante-trois milliards huit cent seize millions trois cent soixante-sept mille quatre-vingt-huitième")
  , (259695496911122585, "deux cent cinquante-neuf billiards six cent quatre-vingt-quinze billions quatre cent quatre-vingt-seize milliards neuf cent onze millions cent vingt-deux mille cinq cent quatre-vingt-cinquième")
  , (420196140727489673, "quatre cent vingt billiards cent quatre-vingt-seize billions cent quarante milliards sept cent vingt-sept millions quatre cent quatre-vingt-neuf mille six cent soixante-treizième")
  , (679891637638612258, "six cent soixante-dix-neuf billiards huit cent quatre-vingt-onze billions six cent trente-sept milliards six cent trente-huit millions six cent douze mille deux cent cinquante-huitième")
  , (1100087778366101931, "un trillion cent billiards quatre-vingt-sept billions sept cent soixante-dix-huit milliards trois cent soixante-six millions cent un mille neuf cent trente et unième")
  , (1779979416004714189, "un trillion sept cent soixante-dix-neuf billiards neuf cent soixante-dix-neuf billions quatre cent seize milliards quatre millions sept cent quatorze mille cent quatre-vingt-neuvième")
  , (2880067194370816120, "deux trillions huit cent quatre-vingts billiards soixante-sept billions cent quatre-vingt-quatorze milliards trois cent soixante-dix millions huit cent seize mille cent vingtième")
  , (4660046610375530309, "quatre trillions six cent soixante billiards quarante-six billions six cent dix milliards trois cent soixante-quinze millions cinq cent trente mille trois cent neuvième")
  , (7540113804746346429, "sept trillions cinq cent quarante billiards cent treize billions huit cent quatre milliards sept cent quarante-six millions trois cent quarante-six mille quatre cent vingt-neuvième")
  , (12200160415121876738, "douze trillions deux cents billiards cent soixante billions quatre cent quinze milliards cent vingt et un millions huit cent soixante-seize mille sept cent trente-huitième")
  , (19740274219868223167, "dix-neuf trillions sept cent quarante billiards deux cent soixante-quatorze billions deux cent dix-neuf milliards huit cent soixante-huit millions deux cent vingt-trois mille cent soixante-septième")
  , (31940434634990099905, "trente et un trillions neuf cent quarante billiards quatre cent trente-quatre billions six cent trente-quatre milliards neuf cent quatre-vingt-dix millions quatre-vingt-dix-neuf mille neuf cent cinquième")
  , (51680708854858323072, "cinquante et un trillions six cent quatre-vingts billiards sept cent huit billions huit cent cinquante-quatre milliards huit cent cinquante-huit millions trois cent vingt-trois mille soixante-douzième")
  , (83621143489848422977, "quatre-vingt-trois trillions six cent vingt et un billiards cent quarante-trois billions quatre cent quatre-vingt-neuf milliards huit cent quarante-huit millions quatre cent vingt-deux mille neuf cent soixante-dix-septième")
  , (135301852344706746049, "cent trente-cinq trillions trois cent un billiards huit cent cinquante-deux billions trois cent quarante-quatre milliards sept cent six millions sept cent quarante-six mille quarante-neuvième")
  , (218922995834555169026, "deux cent dix-huit trillions neuf cent vingt-deux billiards neuf cent quatre-vingt-quinze billions huit cent trente-quatre milliards cinq cent cinquante-cinq millions cent soixante-neuf mille vingt-sixième")
  , (354224848179261915075, "trois cent cinquante-quatre trillions deux cent vingt-quatre billiards huit cent quarante-huit billions cent soixante-dix-neuf milliards deux cent soixante et un millions neuf cent quinze mille soixante-quinzième")
  , (573147844013817084101, "cinq cent soixante-treize trillions cent quarante-sept billiards huit cent quarante-quatre billions treize milliards huit cent dix-sept millions quatre-vingt-quatre mille cent unième")
  , (927372692193078999176, "neuf cent vingt-sept trillions trois cent soixante-douze billiards six cent quatre-vingt-douze billions cent quatre-vingt-treize milliards soixante-dix-huit millions neuf cent quatre-vingt-dix-neuf mille cent soixante-seizième")
  , (1500520536206896083277, "un trilliard cinq cents trillions cinq cent vingt billiards cinq cent trente-six billions deux cent six milliards huit cent quatre-vingt-seize millions quatre-vingt-trois mille deux cent soixante-dix-septième")
  , (2427893228399975082453, "deux trilliards quatre cent vingt-sept trillions huit cent quatre-vingt-treize billiards deux cent vingt-huit billions trois cent quatre-vingt-dix-neuf milliards neuf cent soixante-quinze millions quatre-vingt-deux mille quatre cent cinquante-troisième")
  , (3928413764606871165730, "trois trilliards neuf cent vingt-huit trillions quatre cent treize billiards sept cent soixante-quatre billions six cent six milliards huit cent soixante et onze millions cent soixante-cinq mille sept cent trentième")
  , (6356306993006846248183, "six trilliards trois cent cinquante-six trillions trois cent six billiards neuf cent quatre-vingt-treize billions six milliards huit cent quarante-six millions deux cent quarante-huit mille cent quatre-vingt-troisième")
  , (10284720757613717413913, "dix trilliards deux cent quatre-vingt-quatre trillions sept cent vingt billiards sept cent cinquante-sept billions six cent treize milliards sept cent dix-sept millions quatre cent treize mille neuf cent treizième")
  , (16641027750620563662096, "seize trilliards six cent quarante et un trillions vingt-sept billiards sept cent cinquante billions six cent vingt milliards cinq cent soixante-trois millions six cent soixante-deux mille quatre-vingt-seizième")
  , (26925748508234281076009, "vingt-six trilliards neuf cent vingt-cinq trillions sept cent quarante-huit billiards cinq cent huit billions deux cent trente-quatre milliards deux cent quatre-vingt-un millions soixante-seize mille neuvième")
  , (43566776258854844738105, "quarante-trois trilliards cinq cent soixante-six trillions sept cent soixante-seize billiards deux cent cinquante-huit billions huit cent cinquante-quatre milliards huit cent quarante-quatre millions sept cent trente-huit mille cent cinquième")
  , (70492524767089125814114, "soixante-dix trilliards quatre cent quatre-vingt-douze trillions cinq cent vingt-quatre billiards sept cent soixante-sept billions quatre-vingt-neuf milliards cent vingt-cinq millions huit cent quatorze mille cent quatorzième")
  , (114059301025943970552219, "cent quatorze trilliards cinquante-neuf trillions trois cent un billiards vingt-cinq billions neuf cent quarante-trois milliards neuf cent soixante-dix millions cinq cent cinquante-deux mille deux cent dix-neuvième")
  , (1000, "millième")
  , (10000, "dix millième")
  , (100000, "cent millième")
  , (1000000, "un millionième")
  , (10000000, "dix millionsième")
  , (100000000, "cent millionsième")
  , (1000000000, "un milliardième")
  , (10000000000, "dix milliardsième")
  , (100000000000, "cent milliardsième")
  , (1000000000000, "un billionième")
  , (10000000000000, "dix billionsième")
  , (100000000000000, "cent billionsième")
  , (1000000000000000, "un billiardième")
  , (10000000000000000, "dix billiardsième")
  , (100000000000000000, "cent billiardsième")
  , (1000000000000000000, "un trillionième")
  , (10000000000000000000, "dix trillionsième")
  , (100000000000000000000, "cent trillionsième")
  , (1000000000000000000000, "un trilliardième")
  , (10000000000000000000000, "dix trilliardsième")
  , (100000000000000000000000, "cent trilliardsième")
  , (1000000000000000000000000, "un quadrillionième")
  ]

shortOrdinals :: [(Integer, Text)]
shortOrdinals = [
    (0, "0e")
  , (1, "1e")
  , (2, "2e")
  , (3, "3e")
  , (4, "4e")
  , (5, "5e")
  , (6, "6e")
  , (7, "7e")
  , (8, "8e")
  , (9, "9e")
  , (10, "10e")
  , (11, "11e")
  , (12, "12e")
  , (13, "13e")
  , (14, "14e")
  , (15, "15e")
  , (16, "16e")
  , (17, "17e")
  , (18, "18e")
  , (19, "19e")
  , (20, "20e")
  , (21, "21e")
  , (22, "22e")
  , (23, "23e")
  , (24, "24e")
  , (25, "25e")
  , (26, "26e")
  , (27, "27e")
  , (28, "28e")
  , (29, "29e")
  , (30, "30e")
  , (31, "31e")
  , (32, "32e")
  , (33, "33e")
  , (34, "34e")
  , (35, "35e")
  , (36, "36e")
  , (37, "37e")
  , (38, "38e")
  , (39, "39e")
  , (40, "40e")
  , (41, "41e")
  , (42, "42e")
  , (43, "43e")
  , (44, "44e")
  , (45, "45e")
  , (46, "46e")
  , (47, "47e")
  , (48, "48e")
  , (49, "49e")
  , (50, "50e")
  , (51, "51e")
  , (52, "52e")
  , (53, "53e")
  , (54, "54e")
  , (55, "55e")
  , (56, "56e")
  , (57, "57e")
  , (58, "58e")
  , (59, "59e")
  , (60, "60e")
  , (61, "61e")
  , (62, "62e")
  , (63, "63e")
  , (64, "64e")
  , (65, "65e")
  , (66, "66e")
  , (67, "67e")
  , (68, "68e")
  , (69, "69e")
  , (70, "70e")
  , (71, "71e")
  , (72, "72e")
  , (73, "73e")
  , (74, "74e")
  , (75, "75e")
  , (76, "76e")
  , (77, "77e")
  , (78, "78e")
  , (79, "79e")
  , (80, "80e")
  , (81, "81e")
  , (82, "82e")
  , (83, "83e")
  , (84, "84e")
  , (85, "85e")
  , (86, "86e")
  , (87, "87e")
  , (88, "88e")
  , (89, "89e")
  , (90, "90e")
  , (91, "91e")
  , (92, "92e")
  , (93, "93e")
  , (94, "94e")
  , (95, "95e")
  , (96, "96e")
  , (97, "97e")
  , (98, "98e")
  , (99, "99e")
  , (100, "100e")
  , (101, "101e")
  , (102, "102e")
  , (103, "103e")
  , (104, "104e")
  , (105, "105e")
  , (106, "106e")
  , (107, "107e")
  , (108, "108e")
  , (109, "109e")
  , (110, "110e")
  , (111, "111e")
  , (112, "112e")
  , (113, "113e")
  , (114, "114e")
  , (115, "115e")
  , (116, "116e")
  , (117, "117e")
  , (118, "118e")
  , (119, "119e")
  , (120, "120e")
  , (121, "121e")
  , (122, "122e")
  , (123, "123e")
  , (124, "124e")
  , (125, "125e")
  , (126, "126e")
  , (127, "127e")
  , (128, "128e")
  , (129, "129e")
  , (130, "130e")
  , (131, "131e")
  , (132, "132e")
  , (133, "133e")
  , (134, "134e")
  , (135, "135e")
  , (136, "136e")
  , (137, "137e")
  , (138, "138e")
  , (139, "139e")
  , (140, "140e")
  , (141, "141e")
  , (142, "142e")
  , (143, "143e")
  , (144, "144e")
  , (145, "145e")
  , (146, "146e")
  , (147, "147e")
  , (148, "148e")
  , (149, "149e")
  , (150, "150e")
  , (151, "151e")
  , (152, "152e")
  , (153, "153e")
  , (154, "154e")
  , (155, "155e")
  , (156, "156e")
  , (157, "157e")
  , (158, "158e")
  , (159, "159e")
  , (160, "160e")
  , (161, "161e")
  , (162, "162e")
  , (163, "163e")
  , (164, "164e")
  , (165, "165e")
  , (166, "166e")
  , (167, "167e")
  , (168, "168e")
  , (169, "169e")
  , (170, "170e")
  , (171, "171e")
  , (172, "172e")
  , (173, "173e")
  , (174, "174e")
  , (175, "175e")
  , (176, "176e")
  , (177, "177e")
  , (178, "178e")
  , (179, "179e")
  , (180, "180e")
  , (181, "181e")
  , (182, "182e")
  , (183, "183e")
  , (184, "184e")
  , (185, "185e")
  , (186, "186e")
  , (187, "187e")
  , (188, "188e")
  , (189, "189e")
  , (190, "190e")
  , (191, "191e")
  , (192, "192e")
  , (193, "193e")
  , (194, "194e")
  , (195, "195e")
  , (196, "196e")
  , (197, "197e")
  , (198, "198e")
  , (199, "199e")
  , (200, "200e")
  , (233, "233e")
  , (377, "377e")
  , (610, "610e")
  , (987, "987e")
  , (1597, "1597e")
  , (2584, "2584e")
  , (4181, "4181e")
  , (6765, "6765e")
  , (10946, "10946e")
  , (17711, "17711e")
  , (28657, "28657e")
  , (46368, "46368e")
  , (75025, "75025e")
  , (121393, "121393e")
  , (196418, "196418e")
  , (317811, "317811e")
  , (514229, "514229e")
  , (832040, "832040e")
  , (1346269, "1346269e")
  , (2178309, "2178309e")
  , (3524578, "3524578e")
  , (5702887, "5702887e")
  , (9227465, "9227465e")
  , (14930352, "14930352e")
  , (24157817, "24157817e")
  , (39088169, "39088169e")
  , (63245986, "63245986e")
  , (102334155, "102334155e")
  , (165580141, "165580141e")
  , (267914296, "267914296e")
  , (433494437, "433494437e")
  , (701408733, "701408733e")
  , (1134903170, "1134903170e")
  , (1836311903, "1836311903e")
  , (2971215073, "2971215073e")
  , (4807526976, "4807526976e")
  , (7778742049, "7778742049e")
  , (12586269025, "12586269025e")
  , (20365011074, "20365011074e")
  , (32951280099, "32951280099e")
  , (53316291173, "53316291173e")
  , (86267571272, "86267571272e")
  , (139583862445, "139583862445e")
  , (225851433717, "225851433717e")
  , (365435296162, "365435296162e")
  , (591286729879, "591286729879e")
  , (956722026041, "956722026041e")
  , (1548008755920, "1548008755920e")
  , (2504730781961, "2504730781961e")
  , (4052739537881, "4052739537881e")
  , (6557470319842, "6557470319842e")
  , (10610209857723, "10610209857723e")
  , (17167680177565, "17167680177565e")
  , (27777890035288, "27777890035288e")
  , (44945570212853, "44945570212853e")
  , (72723460248141, "72723460248141e")
  , (117669030460994, "117669030460994e")
  , (190392490709135, "190392490709135e")
  , (308061521170129, "308061521170129e")
  , (498454011879264, "498454011879264e")
  , (806515533049393, "806515533049393e")
  , (1304969544928657, "1304969544928657e")
  , (2111485077978050, "2111485077978050e")
  , (3416454622906707, "3416454622906707e")
  , (5527939700884757, "5527939700884757e")
  , (8944394323791464, "8944394323791464e")
  , (14472334024676221, "14472334024676221e")
  , (23416728348467685, "23416728348467685e")
  , (37889062373143906, "37889062373143906e")
  , (61305790721611591, "61305790721611591e")
  , (99194853094755497, "99194853094755497e")
  , (160500643816367088, "160500643816367088e")
  , (259695496911122585, "259695496911122585e")
  , (420196140727489673, "420196140727489673e")
  , (679891637638612258, "679891637638612258e")
  , (1100087778366101931, "1100087778366101931e")
  , (1779979416004714189, "1779979416004714189e")
  , (2880067194370816120, "2880067194370816120e")
  , (4660046610375530309, "4660046610375530309e")
  , (7540113804746346429, "7540113804746346429e")
  , (12200160415121876738, "12200160415121876738e")
  , (19740274219868223167, "19740274219868223167e")
  , (31940434634990099905, "31940434634990099905e")
  , (51680708854858323072, "51680708854858323072e")
  , (83621143489848422977, "83621143489848422977e")
  , (135301852344706746049, "135301852344706746049e")
  , (218922995834555169026, "218922995834555169026e")
  , (354224848179261915075, "354224848179261915075e")
  , (573147844013817084101, "573147844013817084101e")
  , (927372692193078999176, "927372692193078999176e")
  , (1500520536206896083277, "1500520536206896083277e")
  , (2427893228399975082453, "2427893228399975082453e")
  , (3928413764606871165730, "3928413764606871165730e")
  , (6356306993006846248183, "6356306993006846248183e")
  , (10284720757613717413913, "10284720757613717413913e")
  , (16641027750620563662096, "16641027750620563662096e")
  , (26925748508234281076009, "26925748508234281076009e")
  , (43566776258854844738105, "43566776258854844738105e")
  , (70492524767089125814114, "70492524767089125814114e")
  , (114059301025943970552219, "114059301025943970552219e")
  , (1000, "1000e")
  , (10000, "10000e")
  , (100000, "100000e")
  , (1000000, "1000000e")
  , (10000000, "10000000e")
  , (100000000, "100000000e")
  , (1000000000, "1000000000e")
  , (10000000000, "10000000000e")
  , (100000000000, "100000000000e")
  , (1000000000000, "1000000000000e")
  , (10000000000000, "10000000000000e")
  , (100000000000000, "100000000000000e")
  , (1000000000000000, "1000000000000000e")
  , (10000000000000000, "10000000000000000e")
  , (100000000000000000, "100000000000000000e")
  , (1000000000000000000, "1000000000000000000e")
  , (10000000000000000000, "10000000000000000000e")
  , (100000000000000000000, "100000000000000000000e")
  , (1000000000000000000000, "1000000000000000000000e")
  , (10000000000000000000000, "10000000000000000000000e")
  , (100000000000000000000000, "100000000000000000000000e")
  , (1000000000000000000000000, "1000000000000000000000000e")
  ]

clockTime :: [(TimeOfDay, Text)]
clockTime = [
    (TimeOfDay 0 0 0,"minuit")
  , (TimeOfDay 0 1 0,"douze heures un de la nuit")
  , (TimeOfDay 0 2 0,"douze heures deux de la nuit")
  , (TimeOfDay 0 3 0,"douze heures trois de la nuit")
  , (TimeOfDay 0 4 0,"douze heures quatre de la nuit")
  , (TimeOfDay 0 5 0,"douze heures cinq de la nuit")
  , (TimeOfDay 0 6 0,"douze heures six de la nuit")
  , (TimeOfDay 0 7 0,"douze heures sept de la nuit")
  , (TimeOfDay 0 8 0,"douze heures huit de la nuit")
  , (TimeOfDay 0 9 0,"douze heures neuf de la nuit")
  , (TimeOfDay 0 10 0,"douze heures dix de la nuit")
  , (TimeOfDay 0 11 0,"douze heures onze de la nuit")
  , (TimeOfDay 0 12 0,"douze heures douze de la nuit")
  , (TimeOfDay 0 13 0,"douze heures treize de la nuit")
  , (TimeOfDay 0 14 0,"douze heures quatorze de la nuit")
  , (TimeOfDay 0 15 0,"douze heures et quart de la nuit")
  , (TimeOfDay 0 16 0,"douze heures seize de la nuit")
  , (TimeOfDay 0 17 0,"douze heures dix-sept de la nuit")
  , (TimeOfDay 0 18 0,"douze heures dix-huit de la nuit")
  , (TimeOfDay 0 19 0,"douze heures dix-neuf de la nuit")
  , (TimeOfDay 0 20 0,"douze heures vingt de la nuit")
  , (TimeOfDay 0 21 0,"douze heures vingt et un de la nuit")
  , (TimeOfDay 0 22 0,"douze heures vingt-deux de la nuit")
  , (TimeOfDay 0 23 0,"douze heures vingt-trois de la nuit")
  , (TimeOfDay 0 24 0,"douze heures vingt-quatre de la nuit")
  , (TimeOfDay 0 25 0,"douze heures vingt-cinq de la nuit")
  , (TimeOfDay 0 26 0,"douze heures vingt-six de la nuit")
  , (TimeOfDay 0 27 0,"douze heures vingt-sept de la nuit")
  , (TimeOfDay 0 28 0,"douze heures vingt-huit de la nuit")
  , (TimeOfDay 0 29 0,"douze heures vingt-neuf de la nuit")
  , (TimeOfDay 0 30 0,"douze heures et demie de la nuit")
  , (TimeOfDay 0 31 0,"treize heures moins vingt-neuf de la nuit")
  , (TimeOfDay 0 32 0,"treize heures moins vingt-huit de la nuit")
  , (TimeOfDay 0 33 0,"treize heures moins vingt-sept de la nuit")
  , (TimeOfDay 0 34 0,"treize heures moins vingt-six de la nuit")
  , (TimeOfDay 0 35 0,"treize heures moins vingt-cinq de la nuit")
  , (TimeOfDay 0 36 0,"treize heures moins vingt-quatre de la nuit")
  , (TimeOfDay 0 37 0,"treize heures moins vingt-trois de la nuit")
  , (TimeOfDay 0 38 0,"treize heures moins vingt-deux de la nuit")
  , (TimeOfDay 0 39 0,"treize heures moins vingt et un de la nuit")
  , (TimeOfDay 0 40 0,"treize heures moins vingt de la nuit")
  , (TimeOfDay 0 41 0,"treize heures moins dix-neuf de la nuit")
  , (TimeOfDay 0 42 0,"treize heures moins dix-huit de la nuit")
  , (TimeOfDay 0 43 0,"treize heures moins dix-sept de la nuit")
  , (TimeOfDay 0 44 0,"treize heures moins seize de la nuit")
  , (TimeOfDay 0 45 0,"treize heures moins le quart de la nuit")
  , (TimeOfDay 0 46 0,"treize heures moins quatorze de la nuit")
  , (TimeOfDay 0 47 0,"treize heures moins treize de la nuit")
  , (TimeOfDay 0 48 0,"treize heures moins douze de la nuit")
  , (TimeOfDay 0 49 0,"treize heures moins onze de la nuit")
  , (TimeOfDay 0 50 0,"treize heures moins dix de la nuit")
  , (TimeOfDay 0 51 0,"treize heures moins neuf de la nuit")
  , (TimeOfDay 0 52 0,"treize heures moins huit de la nuit")
  , (TimeOfDay 0 53 0,"treize heures moins sept de la nuit")
  , (TimeOfDay 0 54 0,"treize heures moins six de la nuit")
  , (TimeOfDay 0 55 0,"treize heures moins cinq de la nuit")
  , (TimeOfDay 0 56 0,"treize heures moins quatre de la nuit")
  , (TimeOfDay 0 57 0,"treize heures moins trois de la nuit")
  , (TimeOfDay 0 58 0,"treize heures moins deux de la nuit")
  , (TimeOfDay 0 59 0,"treize heures moins un de la nuit")
  , (TimeOfDay 1 0 0,"une heure de la nuit")
  , (TimeOfDay 1 1 0,"une heure un de la nuit")
  , (TimeOfDay 1 2 0,"une heure deux de la nuit")
  , (TimeOfDay 1 3 0,"une heure trois de la nuit")
  , (TimeOfDay 1 4 0,"une heure quatre de la nuit")
  , (TimeOfDay 1 5 0,"une heure cinq de la nuit")
  , (TimeOfDay 1 6 0,"une heure six de la nuit")
  , (TimeOfDay 1 7 0,"une heure sept de la nuit")
  , (TimeOfDay 1 8 0,"une heure huit de la nuit")
  , (TimeOfDay 1 9 0,"une heure neuf de la nuit")
  , (TimeOfDay 1 10 0,"une heure dix de la nuit")
  , (TimeOfDay 1 11 0,"une heure onze de la nuit")
  , (TimeOfDay 1 12 0,"une heure douze de la nuit")
  , (TimeOfDay 1 13 0,"une heure treize de la nuit")
  , (TimeOfDay 1 14 0,"une heure quatorze de la nuit")
  , (TimeOfDay 1 15 0,"une heure et quart de la nuit")
  , (TimeOfDay 1 16 0,"une heure seize de la nuit")
  , (TimeOfDay 1 17 0,"une heure dix-sept de la nuit")
  , (TimeOfDay 1 18 0,"une heure dix-huit de la nuit")
  , (TimeOfDay 1 19 0,"une heure dix-neuf de la nuit")
  , (TimeOfDay 1 20 0,"une heure vingt de la nuit")
  , (TimeOfDay 1 21 0,"une heure vingt et un de la nuit")
  , (TimeOfDay 1 22 0,"une heure vingt-deux de la nuit")
  , (TimeOfDay 1 23 0,"une heure vingt-trois de la nuit")
  , (TimeOfDay 1 24 0,"une heure vingt-quatre de la nuit")
  , (TimeOfDay 1 25 0,"une heure vingt-cinq de la nuit")
  , (TimeOfDay 1 26 0,"une heure vingt-six de la nuit")
  , (TimeOfDay 1 27 0,"une heure vingt-sept de la nuit")
  , (TimeOfDay 1 28 0,"une heure vingt-huit de la nuit")
  , (TimeOfDay 1 29 0,"une heure vingt-neuf de la nuit")
  , (TimeOfDay 1 30 0,"une heure et demie de la nuit")
  , (TimeOfDay 1 31 0,"deux heures moins vingt-neuf de la nuit")
  , (TimeOfDay 1 32 0,"deux heures moins vingt-huit de la nuit")
  , (TimeOfDay 1 33 0,"deux heures moins vingt-sept de la nuit")
  , (TimeOfDay 1 34 0,"deux heures moins vingt-six de la nuit")
  , (TimeOfDay 1 35 0,"deux heures moins vingt-cinq de la nuit")
  , (TimeOfDay 1 36 0,"deux heures moins vingt-quatre de la nuit")
  , (TimeOfDay 1 37 0,"deux heures moins vingt-trois de la nuit")
  , (TimeOfDay 1 38 0,"deux heures moins vingt-deux de la nuit")
  , (TimeOfDay 1 39 0,"deux heures moins vingt et un de la nuit")
  , (TimeOfDay 1 40 0,"deux heures moins vingt de la nuit")
  , (TimeOfDay 1 41 0,"deux heures moins dix-neuf de la nuit")
  , (TimeOfDay 1 42 0,"deux heures moins dix-huit de la nuit")
  , (TimeOfDay 1 43 0,"deux heures moins dix-sept de la nuit")
  , (TimeOfDay 1 44 0,"deux heures moins seize de la nuit")
  , (TimeOfDay 1 45 0,"deux heures moins le quart de la nuit")
  , (TimeOfDay 1 46 0,"deux heures moins quatorze de la nuit")
  , (TimeOfDay 1 47 0,"deux heures moins treize de la nuit")
  , (TimeOfDay 1 48 0,"deux heures moins douze de la nuit")
  , (TimeOfDay 1 49 0,"deux heures moins onze de la nuit")
  , (TimeOfDay 1 50 0,"deux heures moins dix de la nuit")
  , (TimeOfDay 1 51 0,"deux heures moins neuf de la nuit")
  , (TimeOfDay 1 52 0,"deux heures moins huit de la nuit")
  , (TimeOfDay 1 53 0,"deux heures moins sept de la nuit")
  , (TimeOfDay 1 54 0,"deux heures moins six de la nuit")
  , (TimeOfDay 1 55 0,"deux heures moins cinq de la nuit")
  , (TimeOfDay 1 56 0,"deux heures moins quatre de la nuit")
  , (TimeOfDay 1 57 0,"deux heures moins trois de la nuit")
  , (TimeOfDay 1 58 0,"deux heures moins deux de la nuit")
  , (TimeOfDay 1 59 0,"deux heures moins un de la nuit")
  , (TimeOfDay 2 0 0,"deux heures de la nuit")
  , (TimeOfDay 2 1 0,"deux heures un de la nuit")
  , (TimeOfDay 2 2 0,"deux heures deux de la nuit")
  , (TimeOfDay 2 3 0,"deux heures trois de la nuit")
  , (TimeOfDay 2 4 0,"deux heures quatre de la nuit")
  , (TimeOfDay 2 5 0,"deux heures cinq de la nuit")
  , (TimeOfDay 2 6 0,"deux heures six de la nuit")
  , (TimeOfDay 2 7 0,"deux heures sept de la nuit")
  , (TimeOfDay 2 8 0,"deux heures huit de la nuit")
  , (TimeOfDay 2 9 0,"deux heures neuf de la nuit")
  , (TimeOfDay 2 10 0,"deux heures dix de la nuit")
  , (TimeOfDay 2 11 0,"deux heures onze de la nuit")
  , (TimeOfDay 2 12 0,"deux heures douze de la nuit")
  , (TimeOfDay 2 13 0,"deux heures treize de la nuit")
  , (TimeOfDay 2 14 0,"deux heures quatorze de la nuit")
  , (TimeOfDay 2 15 0,"deux heures et quart de la nuit")
  , (TimeOfDay 2 16 0,"deux heures seize de la nuit")
  , (TimeOfDay 2 17 0,"deux heures dix-sept de la nuit")
  , (TimeOfDay 2 18 0,"deux heures dix-huit de la nuit")
  , (TimeOfDay 2 19 0,"deux heures dix-neuf de la nuit")
  , (TimeOfDay 2 20 0,"deux heures vingt de la nuit")
  , (TimeOfDay 2 21 0,"deux heures vingt et un de la nuit")
  , (TimeOfDay 2 22 0,"deux heures vingt-deux de la nuit")
  , (TimeOfDay 2 23 0,"deux heures vingt-trois de la nuit")
  , (TimeOfDay 2 24 0,"deux heures vingt-quatre de la nuit")
  , (TimeOfDay 2 25 0,"deux heures vingt-cinq de la nuit")
  , (TimeOfDay 2 26 0,"deux heures vingt-six de la nuit")
  , (TimeOfDay 2 27 0,"deux heures vingt-sept de la nuit")
  , (TimeOfDay 2 28 0,"deux heures vingt-huit de la nuit")
  , (TimeOfDay 2 29 0,"deux heures vingt-neuf de la nuit")
  , (TimeOfDay 2 30 0,"deux heures et demie de la nuit")
  , (TimeOfDay 2 31 0,"trois heures moins vingt-neuf de la nuit")
  , (TimeOfDay 2 32 0,"trois heures moins vingt-huit de la nuit")
  , (TimeOfDay 2 33 0,"trois heures moins vingt-sept de la nuit")
  , (TimeOfDay 2 34 0,"trois heures moins vingt-six de la nuit")
  , (TimeOfDay 2 35 0,"trois heures moins vingt-cinq de la nuit")
  , (TimeOfDay 2 36 0,"trois heures moins vingt-quatre de la nuit")
  , (TimeOfDay 2 37 0,"trois heures moins vingt-trois de la nuit")
  , (TimeOfDay 2 38 0,"trois heures moins vingt-deux de la nuit")
  , (TimeOfDay 2 39 0,"trois heures moins vingt et un de la nuit")
  , (TimeOfDay 2 40 0,"trois heures moins vingt de la nuit")
  , (TimeOfDay 2 41 0,"trois heures moins dix-neuf de la nuit")
  , (TimeOfDay 2 42 0,"trois heures moins dix-huit de la nuit")
  , (TimeOfDay 2 43 0,"trois heures moins dix-sept de la nuit")
  , (TimeOfDay 2 44 0,"trois heures moins seize de la nuit")
  , (TimeOfDay 2 45 0,"trois heures moins le quart de la nuit")
  , (TimeOfDay 2 46 0,"trois heures moins quatorze de la nuit")
  , (TimeOfDay 2 47 0,"trois heures moins treize de la nuit")
  , (TimeOfDay 2 48 0,"trois heures moins douze de la nuit")
  , (TimeOfDay 2 49 0,"trois heures moins onze de la nuit")
  , (TimeOfDay 2 50 0,"trois heures moins dix de la nuit")
  , (TimeOfDay 2 51 0,"trois heures moins neuf de la nuit")
  , (TimeOfDay 2 52 0,"trois heures moins huit de la nuit")
  , (TimeOfDay 2 53 0,"trois heures moins sept de la nuit")
  , (TimeOfDay 2 54 0,"trois heures moins six de la nuit")
  , (TimeOfDay 2 55 0,"trois heures moins cinq de la nuit")
  , (TimeOfDay 2 56 0,"trois heures moins quatre de la nuit")
  , (TimeOfDay 2 57 0,"trois heures moins trois de la nuit")
  , (TimeOfDay 2 58 0,"trois heures moins deux de la nuit")
  , (TimeOfDay 2 59 0,"trois heures moins un de la nuit")
  , (TimeOfDay 3 0 0,"trois heures de la nuit")
  , (TimeOfDay 3 1 0,"trois heures un de la nuit")
  , (TimeOfDay 3 2 0,"trois heures deux de la nuit")
  , (TimeOfDay 3 3 0,"trois heures trois de la nuit")
  , (TimeOfDay 3 4 0,"trois heures quatre de la nuit")
  , (TimeOfDay 3 5 0,"trois heures cinq de la nuit")
  , (TimeOfDay 3 6 0,"trois heures six de la nuit")
  , (TimeOfDay 3 7 0,"trois heures sept de la nuit")
  , (TimeOfDay 3 8 0,"trois heures huit de la nuit")
  , (TimeOfDay 3 9 0,"trois heures neuf de la nuit")
  , (TimeOfDay 3 10 0,"trois heures dix de la nuit")
  , (TimeOfDay 3 11 0,"trois heures onze de la nuit")
  , (TimeOfDay 3 12 0,"trois heures douze de la nuit")
  , (TimeOfDay 3 13 0,"trois heures treize de la nuit")
  , (TimeOfDay 3 14 0,"trois heures quatorze de la nuit")
  , (TimeOfDay 3 15 0,"trois heures et quart de la nuit")
  , (TimeOfDay 3 16 0,"trois heures seize de la nuit")
  , (TimeOfDay 3 17 0,"trois heures dix-sept de la nuit")
  , (TimeOfDay 3 18 0,"trois heures dix-huit de la nuit")
  , (TimeOfDay 3 19 0,"trois heures dix-neuf de la nuit")
  , (TimeOfDay 3 20 0,"trois heures vingt de la nuit")
  , (TimeOfDay 3 21 0,"trois heures vingt et un de la nuit")
  , (TimeOfDay 3 22 0,"trois heures vingt-deux de la nuit")
  , (TimeOfDay 3 23 0,"trois heures vingt-trois de la nuit")
  , (TimeOfDay 3 24 0,"trois heures vingt-quatre de la nuit")
  , (TimeOfDay 3 25 0,"trois heures vingt-cinq de la nuit")
  , (TimeOfDay 3 26 0,"trois heures vingt-six de la nuit")
  , (TimeOfDay 3 27 0,"trois heures vingt-sept de la nuit")
  , (TimeOfDay 3 28 0,"trois heures vingt-huit de la nuit")
  , (TimeOfDay 3 29 0,"trois heures vingt-neuf de la nuit")
  , (TimeOfDay 3 30 0,"trois heures et demie de la nuit")
  , (TimeOfDay 3 31 0,"quatre heures moins vingt-neuf de la nuit")
  , (TimeOfDay 3 32 0,"quatre heures moins vingt-huit de la nuit")
  , (TimeOfDay 3 33 0,"quatre heures moins vingt-sept de la nuit")
  , (TimeOfDay 3 34 0,"quatre heures moins vingt-six de la nuit")
  , (TimeOfDay 3 35 0,"quatre heures moins vingt-cinq de la nuit")
  , (TimeOfDay 3 36 0,"quatre heures moins vingt-quatre de la nuit")
  , (TimeOfDay 3 37 0,"quatre heures moins vingt-trois de la nuit")
  , (TimeOfDay 3 38 0,"quatre heures moins vingt-deux de la nuit")
  , (TimeOfDay 3 39 0,"quatre heures moins vingt et un de la nuit")
  , (TimeOfDay 3 40 0,"quatre heures moins vingt de la nuit")
  , (TimeOfDay 3 41 0,"quatre heures moins dix-neuf de la nuit")
  , (TimeOfDay 3 42 0,"quatre heures moins dix-huit de la nuit")
  , (TimeOfDay 3 43 0,"quatre heures moins dix-sept de la nuit")
  , (TimeOfDay 3 44 0,"quatre heures moins seize de la nuit")
  , (TimeOfDay 3 45 0,"quatre heures moins le quart de la nuit")
  , (TimeOfDay 3 46 0,"quatre heures moins quatorze de la nuit")
  , (TimeOfDay 3 47 0,"quatre heures moins treize de la nuit")
  , (TimeOfDay 3 48 0,"quatre heures moins douze de la nuit")
  , (TimeOfDay 3 49 0,"quatre heures moins onze de la nuit")
  , (TimeOfDay 3 50 0,"quatre heures moins dix de la nuit")
  , (TimeOfDay 3 51 0,"quatre heures moins neuf de la nuit")
  , (TimeOfDay 3 52 0,"quatre heures moins huit de la nuit")
  , (TimeOfDay 3 53 0,"quatre heures moins sept de la nuit")
  , (TimeOfDay 3 54 0,"quatre heures moins six de la nuit")
  , (TimeOfDay 3 55 0,"quatre heures moins cinq de la nuit")
  , (TimeOfDay 3 56 0,"quatre heures moins quatre de la nuit")
  , (TimeOfDay 3 57 0,"quatre heures moins trois de la nuit")
  , (TimeOfDay 3 58 0,"quatre heures moins deux de la nuit")
  , (TimeOfDay 3 59 0,"quatre heures moins un de la nuit")
  , (TimeOfDay 4 0 0,"quatre heures de la nuit")
  , (TimeOfDay 4 1 0,"quatre heures un de la nuit")
  , (TimeOfDay 4 2 0,"quatre heures deux de la nuit")
  , (TimeOfDay 4 3 0,"quatre heures trois de la nuit")
  , (TimeOfDay 4 4 0,"quatre heures quatre de la nuit")
  , (TimeOfDay 4 5 0,"quatre heures cinq de la nuit")
  , (TimeOfDay 4 6 0,"quatre heures six de la nuit")
  , (TimeOfDay 4 7 0,"quatre heures sept de la nuit")
  , (TimeOfDay 4 8 0,"quatre heures huit de la nuit")
  , (TimeOfDay 4 9 0,"quatre heures neuf de la nuit")
  , (TimeOfDay 4 10 0,"quatre heures dix de la nuit")
  , (TimeOfDay 4 11 0,"quatre heures onze de la nuit")
  , (TimeOfDay 4 12 0,"quatre heures douze de la nuit")
  , (TimeOfDay 4 13 0,"quatre heures treize de la nuit")
  , (TimeOfDay 4 14 0,"quatre heures quatorze de la nuit")
  , (TimeOfDay 4 15 0,"quatre heures et quart de la nuit")
  , (TimeOfDay 4 16 0,"quatre heures seize de la nuit")
  , (TimeOfDay 4 17 0,"quatre heures dix-sept de la nuit")
  , (TimeOfDay 4 18 0,"quatre heures dix-huit de la nuit")
  , (TimeOfDay 4 19 0,"quatre heures dix-neuf de la nuit")
  , (TimeOfDay 4 20 0,"quatre heures vingt de la nuit")
  , (TimeOfDay 4 21 0,"quatre heures vingt et un de la nuit")
  , (TimeOfDay 4 22 0,"quatre heures vingt-deux de la nuit")
  , (TimeOfDay 4 23 0,"quatre heures vingt-trois de la nuit")
  , (TimeOfDay 4 24 0,"quatre heures vingt-quatre de la nuit")
  , (TimeOfDay 4 25 0,"quatre heures vingt-cinq de la nuit")
  , (TimeOfDay 4 26 0,"quatre heures vingt-six de la nuit")
  , (TimeOfDay 4 27 0,"quatre heures vingt-sept de la nuit")
  , (TimeOfDay 4 28 0,"quatre heures vingt-huit de la nuit")
  , (TimeOfDay 4 29 0,"quatre heures vingt-neuf de la nuit")
  , (TimeOfDay 4 30 0,"quatre heures et demie de la nuit")
  , (TimeOfDay 4 31 0,"cinq heures moins vingt-neuf de la nuit")
  , (TimeOfDay 4 32 0,"cinq heures moins vingt-huit de la nuit")
  , (TimeOfDay 4 33 0,"cinq heures moins vingt-sept de la nuit")
  , (TimeOfDay 4 34 0,"cinq heures moins vingt-six de la nuit")
  , (TimeOfDay 4 35 0,"cinq heures moins vingt-cinq de la nuit")
  , (TimeOfDay 4 36 0,"cinq heures moins vingt-quatre de la nuit")
  , (TimeOfDay 4 37 0,"cinq heures moins vingt-trois de la nuit")
  , (TimeOfDay 4 38 0,"cinq heures moins vingt-deux de la nuit")
  , (TimeOfDay 4 39 0,"cinq heures moins vingt et un de la nuit")
  , (TimeOfDay 4 40 0,"cinq heures moins vingt de la nuit")
  , (TimeOfDay 4 41 0,"cinq heures moins dix-neuf de la nuit")
  , (TimeOfDay 4 42 0,"cinq heures moins dix-huit de la nuit")
  , (TimeOfDay 4 43 0,"cinq heures moins dix-sept de la nuit")
  , (TimeOfDay 4 44 0,"cinq heures moins seize de la nuit")
  , (TimeOfDay 4 45 0,"cinq heures moins le quart de la nuit")
  , (TimeOfDay 4 46 0,"cinq heures moins quatorze de la nuit")
  , (TimeOfDay 4 47 0,"cinq heures moins treize de la nuit")
  , (TimeOfDay 4 48 0,"cinq heures moins douze de la nuit")
  , (TimeOfDay 4 49 0,"cinq heures moins onze de la nuit")
  , (TimeOfDay 4 50 0,"cinq heures moins dix de la nuit")
  , (TimeOfDay 4 51 0,"cinq heures moins neuf de la nuit")
  , (TimeOfDay 4 52 0,"cinq heures moins huit de la nuit")
  , (TimeOfDay 4 53 0,"cinq heures moins sept de la nuit")
  , (TimeOfDay 4 54 0,"cinq heures moins six de la nuit")
  , (TimeOfDay 4 55 0,"cinq heures moins cinq de la nuit")
  , (TimeOfDay 4 56 0,"cinq heures moins quatre de la nuit")
  , (TimeOfDay 4 57 0,"cinq heures moins trois de la nuit")
  , (TimeOfDay 4 58 0,"cinq heures moins deux de la nuit")
  , (TimeOfDay 4 59 0,"cinq heures moins un de la nuit")
  , (TimeOfDay 5 0 0,"cinq heures de la nuit")
  , (TimeOfDay 5 1 0,"cinq heures un de la nuit")
  , (TimeOfDay 5 2 0,"cinq heures deux de la nuit")
  , (TimeOfDay 5 3 0,"cinq heures trois de la nuit")
  , (TimeOfDay 5 4 0,"cinq heures quatre de la nuit")
  , (TimeOfDay 5 5 0,"cinq heures cinq de la nuit")
  , (TimeOfDay 5 6 0,"cinq heures six de la nuit")
  , (TimeOfDay 5 7 0,"cinq heures sept de la nuit")
  , (TimeOfDay 5 8 0,"cinq heures huit de la nuit")
  , (TimeOfDay 5 9 0,"cinq heures neuf de la nuit")
  , (TimeOfDay 5 10 0,"cinq heures dix de la nuit")
  , (TimeOfDay 5 11 0,"cinq heures onze de la nuit")
  , (TimeOfDay 5 12 0,"cinq heures douze de la nuit")
  , (TimeOfDay 5 13 0,"cinq heures treize de la nuit")
  , (TimeOfDay 5 14 0,"cinq heures quatorze de la nuit")
  , (TimeOfDay 5 15 0,"cinq heures et quart de la nuit")
  , (TimeOfDay 5 16 0,"cinq heures seize de la nuit")
  , (TimeOfDay 5 17 0,"cinq heures dix-sept de la nuit")
  , (TimeOfDay 5 18 0,"cinq heures dix-huit de la nuit")
  , (TimeOfDay 5 19 0,"cinq heures dix-neuf de la nuit")
  , (TimeOfDay 5 20 0,"cinq heures vingt de la nuit")
  , (TimeOfDay 5 21 0,"cinq heures vingt et un de la nuit")
  , (TimeOfDay 5 22 0,"cinq heures vingt-deux de la nuit")
  , (TimeOfDay 5 23 0,"cinq heures vingt-trois de la nuit")
  , (TimeOfDay 5 24 0,"cinq heures vingt-quatre de la nuit")
  , (TimeOfDay 5 25 0,"cinq heures vingt-cinq de la nuit")
  , (TimeOfDay 5 26 0,"cinq heures vingt-six de la nuit")
  , (TimeOfDay 5 27 0,"cinq heures vingt-sept de la nuit")
  , (TimeOfDay 5 28 0,"cinq heures vingt-huit de la nuit")
  , (TimeOfDay 5 29 0,"cinq heures vingt-neuf de la nuit")
  , (TimeOfDay 5 30 0,"cinq heures et demie de la nuit")
  , (TimeOfDay 5 31 0,"six heures moins vingt-neuf de la nuit")
  , (TimeOfDay 5 32 0,"six heures moins vingt-huit de la nuit")
  , (TimeOfDay 5 33 0,"six heures moins vingt-sept de la nuit")
  , (TimeOfDay 5 34 0,"six heures moins vingt-six de la nuit")
  , (TimeOfDay 5 35 0,"six heures moins vingt-cinq de la nuit")
  , (TimeOfDay 5 36 0,"six heures moins vingt-quatre de la nuit")
  , (TimeOfDay 5 37 0,"six heures moins vingt-trois de la nuit")
  , (TimeOfDay 5 38 0,"six heures moins vingt-deux de la nuit")
  , (TimeOfDay 5 39 0,"six heures moins vingt et un de la nuit")
  , (TimeOfDay 5 40 0,"six heures moins vingt de la nuit")
  , (TimeOfDay 5 41 0,"six heures moins dix-neuf de la nuit")
  , (TimeOfDay 5 42 0,"six heures moins dix-huit de la nuit")
  , (TimeOfDay 5 43 0,"six heures moins dix-sept de la nuit")
  , (TimeOfDay 5 44 0,"six heures moins seize de la nuit")
  , (TimeOfDay 5 45 0,"six heures moins le quart de la nuit")
  , (TimeOfDay 5 46 0,"six heures moins quatorze de la nuit")
  , (TimeOfDay 5 47 0,"six heures moins treize de la nuit")
  , (TimeOfDay 5 48 0,"six heures moins douze de la nuit")
  , (TimeOfDay 5 49 0,"six heures moins onze de la nuit")
  , (TimeOfDay 5 50 0,"six heures moins dix de la nuit")
  , (TimeOfDay 5 51 0,"six heures moins neuf de la nuit")
  , (TimeOfDay 5 52 0,"six heures moins huit de la nuit")
  , (TimeOfDay 5 53 0,"six heures moins sept de la nuit")
  , (TimeOfDay 5 54 0,"six heures moins six de la nuit")
  , (TimeOfDay 5 55 0,"six heures moins cinq de la nuit")
  , (TimeOfDay 5 56 0,"six heures moins quatre de la nuit")
  , (TimeOfDay 5 57 0,"six heures moins trois de la nuit")
  , (TimeOfDay 5 58 0,"six heures moins deux de la nuit")
  , (TimeOfDay 5 59 0,"six heures moins un de la nuit")
  , (TimeOfDay 6 0 0,"six heures du matin")
  , (TimeOfDay 6 1 0,"six heures un du matin")
  , (TimeOfDay 6 2 0,"six heures deux du matin")
  , (TimeOfDay 6 3 0,"six heures trois du matin")
  , (TimeOfDay 6 4 0,"six heures quatre du matin")
  , (TimeOfDay 6 5 0,"six heures cinq du matin")
  , (TimeOfDay 6 6 0,"six heures six du matin")
  , (TimeOfDay 6 7 0,"six heures sept du matin")
  , (TimeOfDay 6 8 0,"six heures huit du matin")
  , (TimeOfDay 6 9 0,"six heures neuf du matin")
  , (TimeOfDay 6 10 0,"six heures dix du matin")
  , (TimeOfDay 6 11 0,"six heures onze du matin")
  , (TimeOfDay 6 12 0,"six heures douze du matin")
  , (TimeOfDay 6 13 0,"six heures treize du matin")
  , (TimeOfDay 6 14 0,"six heures quatorze du matin")
  , (TimeOfDay 6 15 0,"six heures et quart du matin")
  , (TimeOfDay 6 16 0,"six heures seize du matin")
  , (TimeOfDay 6 17 0,"six heures dix-sept du matin")
  , (TimeOfDay 6 18 0,"six heures dix-huit du matin")
  , (TimeOfDay 6 19 0,"six heures dix-neuf du matin")
  , (TimeOfDay 6 20 0,"six heures vingt du matin")
  , (TimeOfDay 6 21 0,"six heures vingt et un du matin")
  , (TimeOfDay 6 22 0,"six heures vingt-deux du matin")
  , (TimeOfDay 6 23 0,"six heures vingt-trois du matin")
  , (TimeOfDay 6 24 0,"six heures vingt-quatre du matin")
  , (TimeOfDay 6 25 0,"six heures vingt-cinq du matin")
  , (TimeOfDay 6 26 0,"six heures vingt-six du matin")
  , (TimeOfDay 6 27 0,"six heures vingt-sept du matin")
  , (TimeOfDay 6 28 0,"six heures vingt-huit du matin")
  , (TimeOfDay 6 29 0,"six heures vingt-neuf du matin")
  , (TimeOfDay 6 30 0,"six heures et demie du matin")
  , (TimeOfDay 6 31 0,"sept heures moins vingt-neuf du matin")
  , (TimeOfDay 6 32 0,"sept heures moins vingt-huit du matin")
  , (TimeOfDay 6 33 0,"sept heures moins vingt-sept du matin")
  , (TimeOfDay 6 34 0,"sept heures moins vingt-six du matin")
  , (TimeOfDay 6 35 0,"sept heures moins vingt-cinq du matin")
  , (TimeOfDay 6 36 0,"sept heures moins vingt-quatre du matin")
  , (TimeOfDay 6 37 0,"sept heures moins vingt-trois du matin")
  , (TimeOfDay 6 38 0,"sept heures moins vingt-deux du matin")
  , (TimeOfDay 6 39 0,"sept heures moins vingt et un du matin")
  , (TimeOfDay 6 40 0,"sept heures moins vingt du matin")
  , (TimeOfDay 6 41 0,"sept heures moins dix-neuf du matin")
  , (TimeOfDay 6 42 0,"sept heures moins dix-huit du matin")
  , (TimeOfDay 6 43 0,"sept heures moins dix-sept du matin")
  , (TimeOfDay 6 44 0,"sept heures moins seize du matin")
  , (TimeOfDay 6 45 0,"sept heures moins le quart du matin")
  , (TimeOfDay 6 46 0,"sept heures moins quatorze du matin")
  , (TimeOfDay 6 47 0,"sept heures moins treize du matin")
  , (TimeOfDay 6 48 0,"sept heures moins douze du matin")
  , (TimeOfDay 6 49 0,"sept heures moins onze du matin")
  , (TimeOfDay 6 50 0,"sept heures moins dix du matin")
  , (TimeOfDay 6 51 0,"sept heures moins neuf du matin")
  , (TimeOfDay 6 52 0,"sept heures moins huit du matin")
  , (TimeOfDay 6 53 0,"sept heures moins sept du matin")
  , (TimeOfDay 6 54 0,"sept heures moins six du matin")
  , (TimeOfDay 6 55 0,"sept heures moins cinq du matin")
  , (TimeOfDay 6 56 0,"sept heures moins quatre du matin")
  , (TimeOfDay 6 57 0,"sept heures moins trois du matin")
  , (TimeOfDay 6 58 0,"sept heures moins deux du matin")
  , (TimeOfDay 6 59 0,"sept heures moins un du matin")
  , (TimeOfDay 7 0 0,"sept heures du matin")
  , (TimeOfDay 7 1 0,"sept heures un du matin")
  , (TimeOfDay 7 2 0,"sept heures deux du matin")
  , (TimeOfDay 7 3 0,"sept heures trois du matin")
  , (TimeOfDay 7 4 0,"sept heures quatre du matin")
  , (TimeOfDay 7 5 0,"sept heures cinq du matin")
  , (TimeOfDay 7 6 0,"sept heures six du matin")
  , (TimeOfDay 7 7 0,"sept heures sept du matin")
  , (TimeOfDay 7 8 0,"sept heures huit du matin")
  , (TimeOfDay 7 9 0,"sept heures neuf du matin")
  , (TimeOfDay 7 10 0,"sept heures dix du matin")
  , (TimeOfDay 7 11 0,"sept heures onze du matin")
  , (TimeOfDay 7 12 0,"sept heures douze du matin")
  , (TimeOfDay 7 13 0,"sept heures treize du matin")
  , (TimeOfDay 7 14 0,"sept heures quatorze du matin")
  , (TimeOfDay 7 15 0,"sept heures et quart du matin")
  , (TimeOfDay 7 16 0,"sept heures seize du matin")
  , (TimeOfDay 7 17 0,"sept heures dix-sept du matin")
  , (TimeOfDay 7 18 0,"sept heures dix-huit du matin")
  , (TimeOfDay 7 19 0,"sept heures dix-neuf du matin")
  , (TimeOfDay 7 20 0,"sept heures vingt du matin")
  , (TimeOfDay 7 21 0,"sept heures vingt et un du matin")
  , (TimeOfDay 7 22 0,"sept heures vingt-deux du matin")
  , (TimeOfDay 7 23 0,"sept heures vingt-trois du matin")
  , (TimeOfDay 7 24 0,"sept heures vingt-quatre du matin")
  , (TimeOfDay 7 25 0,"sept heures vingt-cinq du matin")
  , (TimeOfDay 7 26 0,"sept heures vingt-six du matin")
  , (TimeOfDay 7 27 0,"sept heures vingt-sept du matin")
  , (TimeOfDay 7 28 0,"sept heures vingt-huit du matin")
  , (TimeOfDay 7 29 0,"sept heures vingt-neuf du matin")
  , (TimeOfDay 7 30 0,"sept heures et demie du matin")
  , (TimeOfDay 7 31 0,"huit heures moins vingt-neuf du matin")
  , (TimeOfDay 7 32 0,"huit heures moins vingt-huit du matin")
  , (TimeOfDay 7 33 0,"huit heures moins vingt-sept du matin")
  , (TimeOfDay 7 34 0,"huit heures moins vingt-six du matin")
  , (TimeOfDay 7 35 0,"huit heures moins vingt-cinq du matin")
  , (TimeOfDay 7 36 0,"huit heures moins vingt-quatre du matin")
  , (TimeOfDay 7 37 0,"huit heures moins vingt-trois du matin")
  , (TimeOfDay 7 38 0,"huit heures moins vingt-deux du matin")
  , (TimeOfDay 7 39 0,"huit heures moins vingt et un du matin")
  , (TimeOfDay 7 40 0,"huit heures moins vingt du matin")
  , (TimeOfDay 7 41 0,"huit heures moins dix-neuf du matin")
  , (TimeOfDay 7 42 0,"huit heures moins dix-huit du matin")
  , (TimeOfDay 7 43 0,"huit heures moins dix-sept du matin")
  , (TimeOfDay 7 44 0,"huit heures moins seize du matin")
  , (TimeOfDay 7 45 0,"huit heures moins le quart du matin")
  , (TimeOfDay 7 46 0,"huit heures moins quatorze du matin")
  , (TimeOfDay 7 47 0,"huit heures moins treize du matin")
  , (TimeOfDay 7 48 0,"huit heures moins douze du matin")
  , (TimeOfDay 7 49 0,"huit heures moins onze du matin")
  , (TimeOfDay 7 50 0,"huit heures moins dix du matin")
  , (TimeOfDay 7 51 0,"huit heures moins neuf du matin")
  , (TimeOfDay 7 52 0,"huit heures moins huit du matin")
  , (TimeOfDay 7 53 0,"huit heures moins sept du matin")
  , (TimeOfDay 7 54 0,"huit heures moins six du matin")
  , (TimeOfDay 7 55 0,"huit heures moins cinq du matin")
  , (TimeOfDay 7 56 0,"huit heures moins quatre du matin")
  , (TimeOfDay 7 57 0,"huit heures moins trois du matin")
  , (TimeOfDay 7 58 0,"huit heures moins deux du matin")
  , (TimeOfDay 7 59 0,"huit heures moins un du matin")
  , (TimeOfDay 8 0 0,"huit heures du matin")
  , (TimeOfDay 8 1 0,"huit heures un du matin")
  , (TimeOfDay 8 2 0,"huit heures deux du matin")
  , (TimeOfDay 8 3 0,"huit heures trois du matin")
  , (TimeOfDay 8 4 0,"huit heures quatre du matin")
  , (TimeOfDay 8 5 0,"huit heures cinq du matin")
  , (TimeOfDay 8 6 0,"huit heures six du matin")
  , (TimeOfDay 8 7 0,"huit heures sept du matin")
  , (TimeOfDay 8 8 0,"huit heures huit du matin")
  , (TimeOfDay 8 9 0,"huit heures neuf du matin")
  , (TimeOfDay 8 10 0,"huit heures dix du matin")
  , (TimeOfDay 8 11 0,"huit heures onze du matin")
  , (TimeOfDay 8 12 0,"huit heures douze du matin")
  , (TimeOfDay 8 13 0,"huit heures treize du matin")
  , (TimeOfDay 8 14 0,"huit heures quatorze du matin")
  , (TimeOfDay 8 15 0,"huit heures et quart du matin")
  , (TimeOfDay 8 16 0,"huit heures seize du matin")
  , (TimeOfDay 8 17 0,"huit heures dix-sept du matin")
  , (TimeOfDay 8 18 0,"huit heures dix-huit du matin")
  , (TimeOfDay 8 19 0,"huit heures dix-neuf du matin")
  , (TimeOfDay 8 20 0,"huit heures vingt du matin")
  , (TimeOfDay 8 21 0,"huit heures vingt et un du matin")
  , (TimeOfDay 8 22 0,"huit heures vingt-deux du matin")
  , (TimeOfDay 8 23 0,"huit heures vingt-trois du matin")
  , (TimeOfDay 8 24 0,"huit heures vingt-quatre du matin")
  , (TimeOfDay 8 25 0,"huit heures vingt-cinq du matin")
  , (TimeOfDay 8 26 0,"huit heures vingt-six du matin")
  , (TimeOfDay 8 27 0,"huit heures vingt-sept du matin")
  , (TimeOfDay 8 28 0,"huit heures vingt-huit du matin")
  , (TimeOfDay 8 29 0,"huit heures vingt-neuf du matin")
  , (TimeOfDay 8 30 0,"huit heures et demie du matin")
  , (TimeOfDay 8 31 0,"neuf heures moins vingt-neuf du matin")
  , (TimeOfDay 8 32 0,"neuf heures moins vingt-huit du matin")
  , (TimeOfDay 8 33 0,"neuf heures moins vingt-sept du matin")
  , (TimeOfDay 8 34 0,"neuf heures moins vingt-six du matin")
  , (TimeOfDay 8 35 0,"neuf heures moins vingt-cinq du matin")
  , (TimeOfDay 8 36 0,"neuf heures moins vingt-quatre du matin")
  , (TimeOfDay 8 37 0,"neuf heures moins vingt-trois du matin")
  , (TimeOfDay 8 38 0,"neuf heures moins vingt-deux du matin")
  , (TimeOfDay 8 39 0,"neuf heures moins vingt et un du matin")
  , (TimeOfDay 8 40 0,"neuf heures moins vingt du matin")
  , (TimeOfDay 8 41 0,"neuf heures moins dix-neuf du matin")
  , (TimeOfDay 8 42 0,"neuf heures moins dix-huit du matin")
  , (TimeOfDay 8 43 0,"neuf heures moins dix-sept du matin")
  , (TimeOfDay 8 44 0,"neuf heures moins seize du matin")
  , (TimeOfDay 8 45 0,"neuf heures moins le quart du matin")
  , (TimeOfDay 8 46 0,"neuf heures moins quatorze du matin")
  , (TimeOfDay 8 47 0,"neuf heures moins treize du matin")
  , (TimeOfDay 8 48 0,"neuf heures moins douze du matin")
  , (TimeOfDay 8 49 0,"neuf heures moins onze du matin")
  , (TimeOfDay 8 50 0,"neuf heures moins dix du matin")
  , (TimeOfDay 8 51 0,"neuf heures moins neuf du matin")
  , (TimeOfDay 8 52 0,"neuf heures moins huit du matin")
  , (TimeOfDay 8 53 0,"neuf heures moins sept du matin")
  , (TimeOfDay 8 54 0,"neuf heures moins six du matin")
  , (TimeOfDay 8 55 0,"neuf heures moins cinq du matin")
  , (TimeOfDay 8 56 0,"neuf heures moins quatre du matin")
  , (TimeOfDay 8 57 0,"neuf heures moins trois du matin")
  , (TimeOfDay 8 58 0,"neuf heures moins deux du matin")
  , (TimeOfDay 8 59 0,"neuf heures moins un du matin")
  , (TimeOfDay 9 0 0,"neuf heures du matin")
  , (TimeOfDay 9 1 0,"neuf heures un du matin")
  , (TimeOfDay 9 2 0,"neuf heures deux du matin")
  , (TimeOfDay 9 3 0,"neuf heures trois du matin")
  , (TimeOfDay 9 4 0,"neuf heures quatre du matin")
  , (TimeOfDay 9 5 0,"neuf heures cinq du matin")
  , (TimeOfDay 9 6 0,"neuf heures six du matin")
  , (TimeOfDay 9 7 0,"neuf heures sept du matin")
  , (TimeOfDay 9 8 0,"neuf heures huit du matin")
  , (TimeOfDay 9 9 0,"neuf heures neuf du matin")
  , (TimeOfDay 9 10 0,"neuf heures dix du matin")
  , (TimeOfDay 9 11 0,"neuf heures onze du matin")
  , (TimeOfDay 9 12 0,"neuf heures douze du matin")
  , (TimeOfDay 9 13 0,"neuf heures treize du matin")
  , (TimeOfDay 9 14 0,"neuf heures quatorze du matin")
  , (TimeOfDay 9 15 0,"neuf heures et quart du matin")
  , (TimeOfDay 9 16 0,"neuf heures seize du matin")
  , (TimeOfDay 9 17 0,"neuf heures dix-sept du matin")
  , (TimeOfDay 9 18 0,"neuf heures dix-huit du matin")
  , (TimeOfDay 9 19 0,"neuf heures dix-neuf du matin")
  , (TimeOfDay 9 20 0,"neuf heures vingt du matin")
  , (TimeOfDay 9 21 0,"neuf heures vingt et un du matin")
  , (TimeOfDay 9 22 0,"neuf heures vingt-deux du matin")
  , (TimeOfDay 9 23 0,"neuf heures vingt-trois du matin")
  , (TimeOfDay 9 24 0,"neuf heures vingt-quatre du matin")
  , (TimeOfDay 9 25 0,"neuf heures vingt-cinq du matin")
  , (TimeOfDay 9 26 0,"neuf heures vingt-six du matin")
  , (TimeOfDay 9 27 0,"neuf heures vingt-sept du matin")
  , (TimeOfDay 9 28 0,"neuf heures vingt-huit du matin")
  , (TimeOfDay 9 29 0,"neuf heures vingt-neuf du matin")
  , (TimeOfDay 9 30 0,"neuf heures et demie du matin")
  , (TimeOfDay 9 31 0,"dix heures moins vingt-neuf du matin")
  , (TimeOfDay 9 32 0,"dix heures moins vingt-huit du matin")
  , (TimeOfDay 9 33 0,"dix heures moins vingt-sept du matin")
  , (TimeOfDay 9 34 0,"dix heures moins vingt-six du matin")
  , (TimeOfDay 9 35 0,"dix heures moins vingt-cinq du matin")
  , (TimeOfDay 9 36 0,"dix heures moins vingt-quatre du matin")
  , (TimeOfDay 9 37 0,"dix heures moins vingt-trois du matin")
  , (TimeOfDay 9 38 0,"dix heures moins vingt-deux du matin")
  , (TimeOfDay 9 39 0,"dix heures moins vingt et un du matin")
  , (TimeOfDay 9 40 0,"dix heures moins vingt du matin")
  , (TimeOfDay 9 41 0,"dix heures moins dix-neuf du matin")
  , (TimeOfDay 9 42 0,"dix heures moins dix-huit du matin")
  , (TimeOfDay 9 43 0,"dix heures moins dix-sept du matin")
  , (TimeOfDay 9 44 0,"dix heures moins seize du matin")
  , (TimeOfDay 9 45 0,"dix heures moins le quart du matin")
  , (TimeOfDay 9 46 0,"dix heures moins quatorze du matin")
  , (TimeOfDay 9 47 0,"dix heures moins treize du matin")
  , (TimeOfDay 9 48 0,"dix heures moins douze du matin")
  , (TimeOfDay 9 49 0,"dix heures moins onze du matin")
  , (TimeOfDay 9 50 0,"dix heures moins dix du matin")
  , (TimeOfDay 9 51 0,"dix heures moins neuf du matin")
  , (TimeOfDay 9 52 0,"dix heures moins huit du matin")
  , (TimeOfDay 9 53 0,"dix heures moins sept du matin")
  , (TimeOfDay 9 54 0,"dix heures moins six du matin")
  , (TimeOfDay 9 55 0,"dix heures moins cinq du matin")
  , (TimeOfDay 9 56 0,"dix heures moins quatre du matin")
  , (TimeOfDay 9 57 0,"dix heures moins trois du matin")
  , (TimeOfDay 9 58 0,"dix heures moins deux du matin")
  , (TimeOfDay 9 59 0,"dix heures moins un du matin")
  , (TimeOfDay 10 0 0,"dix heures du matin")
  , (TimeOfDay 10 1 0,"dix heures un du matin")
  , (TimeOfDay 10 2 0,"dix heures deux du matin")
  , (TimeOfDay 10 3 0,"dix heures trois du matin")
  , (TimeOfDay 10 4 0,"dix heures quatre du matin")
  , (TimeOfDay 10 5 0,"dix heures cinq du matin")
  , (TimeOfDay 10 6 0,"dix heures six du matin")
  , (TimeOfDay 10 7 0,"dix heures sept du matin")
  , (TimeOfDay 10 8 0,"dix heures huit du matin")
  , (TimeOfDay 10 9 0,"dix heures neuf du matin")
  , (TimeOfDay 10 10 0,"dix heures dix du matin")
  , (TimeOfDay 10 11 0,"dix heures onze du matin")
  , (TimeOfDay 10 12 0,"dix heures douze du matin")
  , (TimeOfDay 10 13 0,"dix heures treize du matin")
  , (TimeOfDay 10 14 0,"dix heures quatorze du matin")
  , (TimeOfDay 10 15 0,"dix heures et quart du matin")
  , (TimeOfDay 10 16 0,"dix heures seize du matin")
  , (TimeOfDay 10 17 0,"dix heures dix-sept du matin")
  , (TimeOfDay 10 18 0,"dix heures dix-huit du matin")
  , (TimeOfDay 10 19 0,"dix heures dix-neuf du matin")
  , (TimeOfDay 10 20 0,"dix heures vingt du matin")
  , (TimeOfDay 10 21 0,"dix heures vingt et un du matin")
  , (TimeOfDay 10 22 0,"dix heures vingt-deux du matin")
  , (TimeOfDay 10 23 0,"dix heures vingt-trois du matin")
  , (TimeOfDay 10 24 0,"dix heures vingt-quatre du matin")
  , (TimeOfDay 10 25 0,"dix heures vingt-cinq du matin")
  , (TimeOfDay 10 26 0,"dix heures vingt-six du matin")
  , (TimeOfDay 10 27 0,"dix heures vingt-sept du matin")
  , (TimeOfDay 10 28 0,"dix heures vingt-huit du matin")
  , (TimeOfDay 10 29 0,"dix heures vingt-neuf du matin")
  , (TimeOfDay 10 30 0,"dix heures et demie du matin")
  , (TimeOfDay 10 31 0,"onze heures moins vingt-neuf du matin")
  , (TimeOfDay 10 32 0,"onze heures moins vingt-huit du matin")
  , (TimeOfDay 10 33 0,"onze heures moins vingt-sept du matin")
  , (TimeOfDay 10 34 0,"onze heures moins vingt-six du matin")
  , (TimeOfDay 10 35 0,"onze heures moins vingt-cinq du matin")
  , (TimeOfDay 10 36 0,"onze heures moins vingt-quatre du matin")
  , (TimeOfDay 10 37 0,"onze heures moins vingt-trois du matin")
  , (TimeOfDay 10 38 0,"onze heures moins vingt-deux du matin")
  , (TimeOfDay 10 39 0,"onze heures moins vingt et un du matin")
  , (TimeOfDay 10 40 0,"onze heures moins vingt du matin")
  , (TimeOfDay 10 41 0,"onze heures moins dix-neuf du matin")
  , (TimeOfDay 10 42 0,"onze heures moins dix-huit du matin")
  , (TimeOfDay 10 43 0,"onze heures moins dix-sept du matin")
  , (TimeOfDay 10 44 0,"onze heures moins seize du matin")
  , (TimeOfDay 10 45 0,"onze heures moins le quart du matin")
  , (TimeOfDay 10 46 0,"onze heures moins quatorze du matin")
  , (TimeOfDay 10 47 0,"onze heures moins treize du matin")
  , (TimeOfDay 10 48 0,"onze heures moins douze du matin")
  , (TimeOfDay 10 49 0,"onze heures moins onze du matin")
  , (TimeOfDay 10 50 0,"onze heures moins dix du matin")
  , (TimeOfDay 10 51 0,"onze heures moins neuf du matin")
  , (TimeOfDay 10 52 0,"onze heures moins huit du matin")
  , (TimeOfDay 10 53 0,"onze heures moins sept du matin")
  , (TimeOfDay 10 54 0,"onze heures moins six du matin")
  , (TimeOfDay 10 55 0,"onze heures moins cinq du matin")
  , (TimeOfDay 10 56 0,"onze heures moins quatre du matin")
  , (TimeOfDay 10 57 0,"onze heures moins trois du matin")
  , (TimeOfDay 10 58 0,"onze heures moins deux du matin")
  , (TimeOfDay 10 59 0,"onze heures moins un du matin")
  , (TimeOfDay 11 0 0,"onze heures du matin")
  , (TimeOfDay 11 1 0,"onze heures un du matin")
  , (TimeOfDay 11 2 0,"onze heures deux du matin")
  , (TimeOfDay 11 3 0,"onze heures trois du matin")
  , (TimeOfDay 11 4 0,"onze heures quatre du matin")
  , (TimeOfDay 11 5 0,"onze heures cinq du matin")
  , (TimeOfDay 11 6 0,"onze heures six du matin")
  , (TimeOfDay 11 7 0,"onze heures sept du matin")
  , (TimeOfDay 11 8 0,"onze heures huit du matin")
  , (TimeOfDay 11 9 0,"onze heures neuf du matin")
  , (TimeOfDay 11 10 0,"onze heures dix du matin")
  , (TimeOfDay 11 11 0,"onze heures onze du matin")
  , (TimeOfDay 11 12 0,"onze heures douze du matin")
  , (TimeOfDay 11 13 0,"onze heures treize du matin")
  , (TimeOfDay 11 14 0,"onze heures quatorze du matin")
  , (TimeOfDay 11 15 0,"onze heures et quart du matin")
  , (TimeOfDay 11 16 0,"onze heures seize du matin")
  , (TimeOfDay 11 17 0,"onze heures dix-sept du matin")
  , (TimeOfDay 11 18 0,"onze heures dix-huit du matin")
  , (TimeOfDay 11 19 0,"onze heures dix-neuf du matin")
  , (TimeOfDay 11 20 0,"onze heures vingt du matin")
  , (TimeOfDay 11 21 0,"onze heures vingt et un du matin")
  , (TimeOfDay 11 22 0,"onze heures vingt-deux du matin")
  , (TimeOfDay 11 23 0,"onze heures vingt-trois du matin")
  , (TimeOfDay 11 24 0,"onze heures vingt-quatre du matin")
  , (TimeOfDay 11 25 0,"onze heures vingt-cinq du matin")
  , (TimeOfDay 11 26 0,"onze heures vingt-six du matin")
  , (TimeOfDay 11 27 0,"onze heures vingt-sept du matin")
  , (TimeOfDay 11 28 0,"onze heures vingt-huit du matin")
  , (TimeOfDay 11 29 0,"onze heures vingt-neuf du matin")
  , (TimeOfDay 11 30 0,"onze heures et demie du matin")
  , (TimeOfDay 11 31 0,"douze heures moins vingt-neuf du matin")
  , (TimeOfDay 11 32 0,"douze heures moins vingt-huit du matin")
  , (TimeOfDay 11 33 0,"douze heures moins vingt-sept du matin")
  , (TimeOfDay 11 34 0,"douze heures moins vingt-six du matin")
  , (TimeOfDay 11 35 0,"douze heures moins vingt-cinq du matin")
  , (TimeOfDay 11 36 0,"douze heures moins vingt-quatre du matin")
  , (TimeOfDay 11 37 0,"douze heures moins vingt-trois du matin")
  , (TimeOfDay 11 38 0,"douze heures moins vingt-deux du matin")
  , (TimeOfDay 11 39 0,"douze heures moins vingt et un du matin")
  , (TimeOfDay 11 40 0,"douze heures moins vingt du matin")
  , (TimeOfDay 11 41 0,"douze heures moins dix-neuf du matin")
  , (TimeOfDay 11 42 0,"douze heures moins dix-huit du matin")
  , (TimeOfDay 11 43 0,"douze heures moins dix-sept du matin")
  , (TimeOfDay 11 44 0,"douze heures moins seize du matin")
  , (TimeOfDay 11 45 0,"douze heures moins le quart du matin")
  , (TimeOfDay 11 46 0,"douze heures moins quatorze du matin")
  , (TimeOfDay 11 47 0,"douze heures moins treize du matin")
  , (TimeOfDay 11 48 0,"douze heures moins douze du matin")
  , (TimeOfDay 11 49 0,"douze heures moins onze du matin")
  , (TimeOfDay 11 50 0,"douze heures moins dix du matin")
  , (TimeOfDay 11 51 0,"douze heures moins neuf du matin")
  , (TimeOfDay 11 52 0,"douze heures moins huit du matin")
  , (TimeOfDay 11 53 0,"douze heures moins sept du matin")
  , (TimeOfDay 11 54 0,"douze heures moins six du matin")
  , (TimeOfDay 11 55 0,"douze heures moins cinq du matin")
  , (TimeOfDay 11 56 0,"douze heures moins quatre du matin")
  , (TimeOfDay 11 57 0,"douze heures moins trois du matin")
  , (TimeOfDay 11 58 0,"douze heures moins deux du matin")
  , (TimeOfDay 11 59 0,"douze heures moins un du matin")
  , (TimeOfDay 12 0 0,"midi")
  , (TimeOfDay 12 1 0,"douze heures un de l'apr\232s-midi")
  , (TimeOfDay 12 2 0,"douze heures deux de l'apr\232s-midi")
  , (TimeOfDay 12 3 0,"douze heures trois de l'apr\232s-midi")
  , (TimeOfDay 12 4 0,"douze heures quatre de l'apr\232s-midi")
  , (TimeOfDay 12 5 0,"douze heures cinq de l'apr\232s-midi")
  , (TimeOfDay 12 6 0,"douze heures six de l'apr\232s-midi")
  , (TimeOfDay 12 7 0,"douze heures sept de l'apr\232s-midi")
  , (TimeOfDay 12 8 0,"douze heures huit de l'apr\232s-midi")
  , (TimeOfDay 12 9 0,"douze heures neuf de l'apr\232s-midi")
  , (TimeOfDay 12 10 0,"douze heures dix de l'apr\232s-midi")
  , (TimeOfDay 12 11 0,"douze heures onze de l'apr\232s-midi")
  , (TimeOfDay 12 12 0,"douze heures douze de l'apr\232s-midi")
  , (TimeOfDay 12 13 0,"douze heures treize de l'apr\232s-midi")
  , (TimeOfDay 12 14 0,"douze heures quatorze de l'apr\232s-midi")
  , (TimeOfDay 12 15 0,"douze heures et quart de l'apr\232s-midi")
  , (TimeOfDay 12 16 0,"douze heures seize de l'apr\232s-midi")
  , (TimeOfDay 12 17 0,"douze heures dix-sept de l'apr\232s-midi")
  , (TimeOfDay 12 18 0,"douze heures dix-huit de l'apr\232s-midi")
  , (TimeOfDay 12 19 0,"douze heures dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 12 20 0,"douze heures vingt de l'apr\232s-midi")
  , (TimeOfDay 12 21 0,"douze heures vingt et un de l'apr\232s-midi")
  , (TimeOfDay 12 22 0,"douze heures vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 12 23 0,"douze heures vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 12 24 0,"douze heures vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 12 25 0,"douze heures vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 12 26 0,"douze heures vingt-six de l'apr\232s-midi")
  , (TimeOfDay 12 27 0,"douze heures vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 12 28 0,"douze heures vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 12 29 0,"douze heures vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 12 30 0,"douze heures et demie de l'apr\232s-midi")
  , (TimeOfDay 12 31 0,"treize heures moins vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 12 32 0,"treize heures moins vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 12 33 0,"treize heures moins vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 12 34 0,"treize heures moins vingt-six de l'apr\232s-midi")
  , (TimeOfDay 12 35 0,"treize heures moins vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 12 36 0,"treize heures moins vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 12 37 0,"treize heures moins vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 12 38 0,"treize heures moins vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 12 39 0,"treize heures moins vingt et un de l'apr\232s-midi")
  , (TimeOfDay 12 40 0,"treize heures moins vingt de l'apr\232s-midi")
  , (TimeOfDay 12 41 0,"treize heures moins dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 12 42 0,"treize heures moins dix-huit de l'apr\232s-midi")
  , (TimeOfDay 12 43 0,"treize heures moins dix-sept de l'apr\232s-midi")
  , (TimeOfDay 12 44 0,"treize heures moins seize de l'apr\232s-midi")
  , (TimeOfDay 12 45 0,"treize heures moins le quart de l'apr\232s-midi")
  , (TimeOfDay 12 46 0,"treize heures moins quatorze de l'apr\232s-midi")
  , (TimeOfDay 12 47 0,"treize heures moins treize de l'apr\232s-midi")
  , (TimeOfDay 12 48 0,"treize heures moins douze de l'apr\232s-midi")
  , (TimeOfDay 12 49 0,"treize heures moins onze de l'apr\232s-midi")
  , (TimeOfDay 12 50 0,"treize heures moins dix de l'apr\232s-midi")
  , (TimeOfDay 12 51 0,"treize heures moins neuf de l'apr\232s-midi")
  , (TimeOfDay 12 52 0,"treize heures moins huit de l'apr\232s-midi")
  , (TimeOfDay 12 53 0,"treize heures moins sept de l'apr\232s-midi")
  , (TimeOfDay 12 54 0,"treize heures moins six de l'apr\232s-midi")
  , (TimeOfDay 12 55 0,"treize heures moins cinq de l'apr\232s-midi")
  , (TimeOfDay 12 56 0,"treize heures moins quatre de l'apr\232s-midi")
  , (TimeOfDay 12 57 0,"treize heures moins trois de l'apr\232s-midi")
  , (TimeOfDay 12 58 0,"treize heures moins deux de l'apr\232s-midi")
  , (TimeOfDay 12 59 0,"treize heures moins un de l'apr\232s-midi")
  , (TimeOfDay 13 0 0,"une heure de l'apr\232s-midi")
  , (TimeOfDay 13 1 0,"une heure un de l'apr\232s-midi")
  , (TimeOfDay 13 2 0,"une heure deux de l'apr\232s-midi")
  , (TimeOfDay 13 3 0,"une heure trois de l'apr\232s-midi")
  , (TimeOfDay 13 4 0,"une heure quatre de l'apr\232s-midi")
  , (TimeOfDay 13 5 0,"une heure cinq de l'apr\232s-midi")
  , (TimeOfDay 13 6 0,"une heure six de l'apr\232s-midi")
  , (TimeOfDay 13 7 0,"une heure sept de l'apr\232s-midi")
  , (TimeOfDay 13 8 0,"une heure huit de l'apr\232s-midi")
  , (TimeOfDay 13 9 0,"une heure neuf de l'apr\232s-midi")
  , (TimeOfDay 13 10 0,"une heure dix de l'apr\232s-midi")
  , (TimeOfDay 13 11 0,"une heure onze de l'apr\232s-midi")
  , (TimeOfDay 13 12 0,"une heure douze de l'apr\232s-midi")
  , (TimeOfDay 13 13 0,"une heure treize de l'apr\232s-midi")
  , (TimeOfDay 13 14 0,"une heure quatorze de l'apr\232s-midi")
  , (TimeOfDay 13 15 0,"une heure et quart de l'apr\232s-midi")
  , (TimeOfDay 13 16 0,"une heure seize de l'apr\232s-midi")
  , (TimeOfDay 13 17 0,"une heure dix-sept de l'apr\232s-midi")
  , (TimeOfDay 13 18 0,"une heure dix-huit de l'apr\232s-midi")
  , (TimeOfDay 13 19 0,"une heure dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 13 20 0,"une heure vingt de l'apr\232s-midi")
  , (TimeOfDay 13 21 0,"une heure vingt et un de l'apr\232s-midi")
  , (TimeOfDay 13 22 0,"une heure vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 13 23 0,"une heure vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 13 24 0,"une heure vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 13 25 0,"une heure vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 13 26 0,"une heure vingt-six de l'apr\232s-midi")
  , (TimeOfDay 13 27 0,"une heure vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 13 28 0,"une heure vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 13 29 0,"une heure vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 13 30 0,"une heure et demie de l'apr\232s-midi")
  , (TimeOfDay 13 31 0,"deux heures moins vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 13 32 0,"deux heures moins vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 13 33 0,"deux heures moins vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 13 34 0,"deux heures moins vingt-six de l'apr\232s-midi")
  , (TimeOfDay 13 35 0,"deux heures moins vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 13 36 0,"deux heures moins vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 13 37 0,"deux heures moins vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 13 38 0,"deux heures moins vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 13 39 0,"deux heures moins vingt et un de l'apr\232s-midi")
  , (TimeOfDay 13 40 0,"deux heures moins vingt de l'apr\232s-midi")
  , (TimeOfDay 13 41 0,"deux heures moins dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 13 42 0,"deux heures moins dix-huit de l'apr\232s-midi")
  , (TimeOfDay 13 43 0,"deux heures moins dix-sept de l'apr\232s-midi")
  , (TimeOfDay 13 44 0,"deux heures moins seize de l'apr\232s-midi")
  , (TimeOfDay 13 45 0,"deux heures moins le quart de l'apr\232s-midi")
  , (TimeOfDay 13 46 0,"deux heures moins quatorze de l'apr\232s-midi")
  , (TimeOfDay 13 47 0,"deux heures moins treize de l'apr\232s-midi")
  , (TimeOfDay 13 48 0,"deux heures moins douze de l'apr\232s-midi")
  , (TimeOfDay 13 49 0,"deux heures moins onze de l'apr\232s-midi")
  , (TimeOfDay 13 50 0,"deux heures moins dix de l'apr\232s-midi")
  , (TimeOfDay 13 51 0,"deux heures moins neuf de l'apr\232s-midi")
  , (TimeOfDay 13 52 0,"deux heures moins huit de l'apr\232s-midi")
  , (TimeOfDay 13 53 0,"deux heures moins sept de l'apr\232s-midi")
  , (TimeOfDay 13 54 0,"deux heures moins six de l'apr\232s-midi")
  , (TimeOfDay 13 55 0,"deux heures moins cinq de l'apr\232s-midi")
  , (TimeOfDay 13 56 0,"deux heures moins quatre de l'apr\232s-midi")
  , (TimeOfDay 13 57 0,"deux heures moins trois de l'apr\232s-midi")
  , (TimeOfDay 13 58 0,"deux heures moins deux de l'apr\232s-midi")
  , (TimeOfDay 13 59 0,"deux heures moins un de l'apr\232s-midi")
  , (TimeOfDay 14 0 0,"deux heures de l'apr\232s-midi")
  , (TimeOfDay 14 1 0,"deux heures un de l'apr\232s-midi")
  , (TimeOfDay 14 2 0,"deux heures deux de l'apr\232s-midi")
  , (TimeOfDay 14 3 0,"deux heures trois de l'apr\232s-midi")
  , (TimeOfDay 14 4 0,"deux heures quatre de l'apr\232s-midi")
  , (TimeOfDay 14 5 0,"deux heures cinq de l'apr\232s-midi")
  , (TimeOfDay 14 6 0,"deux heures six de l'apr\232s-midi")
  , (TimeOfDay 14 7 0,"deux heures sept de l'apr\232s-midi")
  , (TimeOfDay 14 8 0,"deux heures huit de l'apr\232s-midi")
  , (TimeOfDay 14 9 0,"deux heures neuf de l'apr\232s-midi")
  , (TimeOfDay 14 10 0,"deux heures dix de l'apr\232s-midi")
  , (TimeOfDay 14 11 0,"deux heures onze de l'apr\232s-midi")
  , (TimeOfDay 14 12 0,"deux heures douze de l'apr\232s-midi")
  , (TimeOfDay 14 13 0,"deux heures treize de l'apr\232s-midi")
  , (TimeOfDay 14 14 0,"deux heures quatorze de l'apr\232s-midi")
  , (TimeOfDay 14 15 0,"deux heures et quart de l'apr\232s-midi")
  , (TimeOfDay 14 16 0,"deux heures seize de l'apr\232s-midi")
  , (TimeOfDay 14 17 0,"deux heures dix-sept de l'apr\232s-midi")
  , (TimeOfDay 14 18 0,"deux heures dix-huit de l'apr\232s-midi")
  , (TimeOfDay 14 19 0,"deux heures dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 14 20 0,"deux heures vingt de l'apr\232s-midi")
  , (TimeOfDay 14 21 0,"deux heures vingt et un de l'apr\232s-midi")
  , (TimeOfDay 14 22 0,"deux heures vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 14 23 0,"deux heures vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 14 24 0,"deux heures vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 14 25 0,"deux heures vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 14 26 0,"deux heures vingt-six de l'apr\232s-midi")
  , (TimeOfDay 14 27 0,"deux heures vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 14 28 0,"deux heures vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 14 29 0,"deux heures vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 14 30 0,"deux heures et demie de l'apr\232s-midi")
  , (TimeOfDay 14 31 0,"trois heures moins vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 14 32 0,"trois heures moins vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 14 33 0,"trois heures moins vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 14 34 0,"trois heures moins vingt-six de l'apr\232s-midi")
  , (TimeOfDay 14 35 0,"trois heures moins vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 14 36 0,"trois heures moins vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 14 37 0,"trois heures moins vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 14 38 0,"trois heures moins vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 14 39 0,"trois heures moins vingt et un de l'apr\232s-midi")
  , (TimeOfDay 14 40 0,"trois heures moins vingt de l'apr\232s-midi")
  , (TimeOfDay 14 41 0,"trois heures moins dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 14 42 0,"trois heures moins dix-huit de l'apr\232s-midi")
  , (TimeOfDay 14 43 0,"trois heures moins dix-sept de l'apr\232s-midi")
  , (TimeOfDay 14 44 0,"trois heures moins seize de l'apr\232s-midi")
  , (TimeOfDay 14 45 0,"trois heures moins le quart de l'apr\232s-midi")
  , (TimeOfDay 14 46 0,"trois heures moins quatorze de l'apr\232s-midi")
  , (TimeOfDay 14 47 0,"trois heures moins treize de l'apr\232s-midi")
  , (TimeOfDay 14 48 0,"trois heures moins douze de l'apr\232s-midi")
  , (TimeOfDay 14 49 0,"trois heures moins onze de l'apr\232s-midi")
  , (TimeOfDay 14 50 0,"trois heures moins dix de l'apr\232s-midi")
  , (TimeOfDay 14 51 0,"trois heures moins neuf de l'apr\232s-midi")
  , (TimeOfDay 14 52 0,"trois heures moins huit de l'apr\232s-midi")
  , (TimeOfDay 14 53 0,"trois heures moins sept de l'apr\232s-midi")
  , (TimeOfDay 14 54 0,"trois heures moins six de l'apr\232s-midi")
  , (TimeOfDay 14 55 0,"trois heures moins cinq de l'apr\232s-midi")
  , (TimeOfDay 14 56 0,"trois heures moins quatre de l'apr\232s-midi")
  , (TimeOfDay 14 57 0,"trois heures moins trois de l'apr\232s-midi")
  , (TimeOfDay 14 58 0,"trois heures moins deux de l'apr\232s-midi")
  , (TimeOfDay 14 59 0,"trois heures moins un de l'apr\232s-midi")
  , (TimeOfDay 15 0 0,"trois heures de l'apr\232s-midi")
  , (TimeOfDay 15 1 0,"trois heures un de l'apr\232s-midi")
  , (TimeOfDay 15 2 0,"trois heures deux de l'apr\232s-midi")
  , (TimeOfDay 15 3 0,"trois heures trois de l'apr\232s-midi")
  , (TimeOfDay 15 4 0,"trois heures quatre de l'apr\232s-midi")
  , (TimeOfDay 15 5 0,"trois heures cinq de l'apr\232s-midi")
  , (TimeOfDay 15 6 0,"trois heures six de l'apr\232s-midi")
  , (TimeOfDay 15 7 0,"trois heures sept de l'apr\232s-midi")
  , (TimeOfDay 15 8 0,"trois heures huit de l'apr\232s-midi")
  , (TimeOfDay 15 9 0,"trois heures neuf de l'apr\232s-midi")
  , (TimeOfDay 15 10 0,"trois heures dix de l'apr\232s-midi")
  , (TimeOfDay 15 11 0,"trois heures onze de l'apr\232s-midi")
  , (TimeOfDay 15 12 0,"trois heures douze de l'apr\232s-midi")
  , (TimeOfDay 15 13 0,"trois heures treize de l'apr\232s-midi")
  , (TimeOfDay 15 14 0,"trois heures quatorze de l'apr\232s-midi")
  , (TimeOfDay 15 15 0,"trois heures et quart de l'apr\232s-midi")
  , (TimeOfDay 15 16 0,"trois heures seize de l'apr\232s-midi")
  , (TimeOfDay 15 17 0,"trois heures dix-sept de l'apr\232s-midi")
  , (TimeOfDay 15 18 0,"trois heures dix-huit de l'apr\232s-midi")
  , (TimeOfDay 15 19 0,"trois heures dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 15 20 0,"trois heures vingt de l'apr\232s-midi")
  , (TimeOfDay 15 21 0,"trois heures vingt et un de l'apr\232s-midi")
  , (TimeOfDay 15 22 0,"trois heures vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 15 23 0,"trois heures vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 15 24 0,"trois heures vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 15 25 0,"trois heures vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 15 26 0,"trois heures vingt-six de l'apr\232s-midi")
  , (TimeOfDay 15 27 0,"trois heures vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 15 28 0,"trois heures vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 15 29 0,"trois heures vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 15 30 0,"trois heures et demie de l'apr\232s-midi")
  , (TimeOfDay 15 31 0,"quatre heures moins vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 15 32 0,"quatre heures moins vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 15 33 0,"quatre heures moins vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 15 34 0,"quatre heures moins vingt-six de l'apr\232s-midi")
  , (TimeOfDay 15 35 0,"quatre heures moins vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 15 36 0,"quatre heures moins vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 15 37 0,"quatre heures moins vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 15 38 0,"quatre heures moins vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 15 39 0,"quatre heures moins vingt et un de l'apr\232s-midi")
  , (TimeOfDay 15 40 0,"quatre heures moins vingt de l'apr\232s-midi")
  , (TimeOfDay 15 41 0,"quatre heures moins dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 15 42 0,"quatre heures moins dix-huit de l'apr\232s-midi")
  , (TimeOfDay 15 43 0,"quatre heures moins dix-sept de l'apr\232s-midi")
  , (TimeOfDay 15 44 0,"quatre heures moins seize de l'apr\232s-midi")
  , (TimeOfDay 15 45 0,"quatre heures moins le quart de l'apr\232s-midi")
  , (TimeOfDay 15 46 0,"quatre heures moins quatorze de l'apr\232s-midi")
  , (TimeOfDay 15 47 0,"quatre heures moins treize de l'apr\232s-midi")
  , (TimeOfDay 15 48 0,"quatre heures moins douze de l'apr\232s-midi")
  , (TimeOfDay 15 49 0,"quatre heures moins onze de l'apr\232s-midi")
  , (TimeOfDay 15 50 0,"quatre heures moins dix de l'apr\232s-midi")
  , (TimeOfDay 15 51 0,"quatre heures moins neuf de l'apr\232s-midi")
  , (TimeOfDay 15 52 0,"quatre heures moins huit de l'apr\232s-midi")
  , (TimeOfDay 15 53 0,"quatre heures moins sept de l'apr\232s-midi")
  , (TimeOfDay 15 54 0,"quatre heures moins six de l'apr\232s-midi")
  , (TimeOfDay 15 55 0,"quatre heures moins cinq de l'apr\232s-midi")
  , (TimeOfDay 15 56 0,"quatre heures moins quatre de l'apr\232s-midi")
  , (TimeOfDay 15 57 0,"quatre heures moins trois de l'apr\232s-midi")
  , (TimeOfDay 15 58 0,"quatre heures moins deux de l'apr\232s-midi")
  , (TimeOfDay 15 59 0,"quatre heures moins un de l'apr\232s-midi")
  , (TimeOfDay 16 0 0,"quatre heures de l'apr\232s-midi")
  , (TimeOfDay 16 1 0,"quatre heures un de l'apr\232s-midi")
  , (TimeOfDay 16 2 0,"quatre heures deux de l'apr\232s-midi")
  , (TimeOfDay 16 3 0,"quatre heures trois de l'apr\232s-midi")
  , (TimeOfDay 16 4 0,"quatre heures quatre de l'apr\232s-midi")
  , (TimeOfDay 16 5 0,"quatre heures cinq de l'apr\232s-midi")
  , (TimeOfDay 16 6 0,"quatre heures six de l'apr\232s-midi")
  , (TimeOfDay 16 7 0,"quatre heures sept de l'apr\232s-midi")
  , (TimeOfDay 16 8 0,"quatre heures huit de l'apr\232s-midi")
  , (TimeOfDay 16 9 0,"quatre heures neuf de l'apr\232s-midi")
  , (TimeOfDay 16 10 0,"quatre heures dix de l'apr\232s-midi")
  , (TimeOfDay 16 11 0,"quatre heures onze de l'apr\232s-midi")
  , (TimeOfDay 16 12 0,"quatre heures douze de l'apr\232s-midi")
  , (TimeOfDay 16 13 0,"quatre heures treize de l'apr\232s-midi")
  , (TimeOfDay 16 14 0,"quatre heures quatorze de l'apr\232s-midi")
  , (TimeOfDay 16 15 0,"quatre heures et quart de l'apr\232s-midi")
  , (TimeOfDay 16 16 0,"quatre heures seize de l'apr\232s-midi")
  , (TimeOfDay 16 17 0,"quatre heures dix-sept de l'apr\232s-midi")
  , (TimeOfDay 16 18 0,"quatre heures dix-huit de l'apr\232s-midi")
  , (TimeOfDay 16 19 0,"quatre heures dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 16 20 0,"quatre heures vingt de l'apr\232s-midi")
  , (TimeOfDay 16 21 0,"quatre heures vingt et un de l'apr\232s-midi")
  , (TimeOfDay 16 22 0,"quatre heures vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 16 23 0,"quatre heures vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 16 24 0,"quatre heures vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 16 25 0,"quatre heures vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 16 26 0,"quatre heures vingt-six de l'apr\232s-midi")
  , (TimeOfDay 16 27 0,"quatre heures vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 16 28 0,"quatre heures vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 16 29 0,"quatre heures vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 16 30 0,"quatre heures et demie de l'apr\232s-midi")
  , (TimeOfDay 16 31 0,"cinq heures moins vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 16 32 0,"cinq heures moins vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 16 33 0,"cinq heures moins vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 16 34 0,"cinq heures moins vingt-six de l'apr\232s-midi")
  , (TimeOfDay 16 35 0,"cinq heures moins vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 16 36 0,"cinq heures moins vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 16 37 0,"cinq heures moins vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 16 38 0,"cinq heures moins vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 16 39 0,"cinq heures moins vingt et un de l'apr\232s-midi")
  , (TimeOfDay 16 40 0,"cinq heures moins vingt de l'apr\232s-midi")
  , (TimeOfDay 16 41 0,"cinq heures moins dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 16 42 0,"cinq heures moins dix-huit de l'apr\232s-midi")
  , (TimeOfDay 16 43 0,"cinq heures moins dix-sept de l'apr\232s-midi")
  , (TimeOfDay 16 44 0,"cinq heures moins seize de l'apr\232s-midi")
  , (TimeOfDay 16 45 0,"cinq heures moins le quart de l'apr\232s-midi")
  , (TimeOfDay 16 46 0,"cinq heures moins quatorze de l'apr\232s-midi")
  , (TimeOfDay 16 47 0,"cinq heures moins treize de l'apr\232s-midi")
  , (TimeOfDay 16 48 0,"cinq heures moins douze de l'apr\232s-midi")
  , (TimeOfDay 16 49 0,"cinq heures moins onze de l'apr\232s-midi")
  , (TimeOfDay 16 50 0,"cinq heures moins dix de l'apr\232s-midi")
  , (TimeOfDay 16 51 0,"cinq heures moins neuf de l'apr\232s-midi")
  , (TimeOfDay 16 52 0,"cinq heures moins huit de l'apr\232s-midi")
  , (TimeOfDay 16 53 0,"cinq heures moins sept de l'apr\232s-midi")
  , (TimeOfDay 16 54 0,"cinq heures moins six de l'apr\232s-midi")
  , (TimeOfDay 16 55 0,"cinq heures moins cinq de l'apr\232s-midi")
  , (TimeOfDay 16 56 0,"cinq heures moins quatre de l'apr\232s-midi")
  , (TimeOfDay 16 57 0,"cinq heures moins trois de l'apr\232s-midi")
  , (TimeOfDay 16 58 0,"cinq heures moins deux de l'apr\232s-midi")
  , (TimeOfDay 16 59 0,"cinq heures moins un de l'apr\232s-midi")
  , (TimeOfDay 17 0 0,"cinq heures de l'apr\232s-midi")
  , (TimeOfDay 17 1 0,"cinq heures un de l'apr\232s-midi")
  , (TimeOfDay 17 2 0,"cinq heures deux de l'apr\232s-midi")
  , (TimeOfDay 17 3 0,"cinq heures trois de l'apr\232s-midi")
  , (TimeOfDay 17 4 0,"cinq heures quatre de l'apr\232s-midi")
  , (TimeOfDay 17 5 0,"cinq heures cinq de l'apr\232s-midi")
  , (TimeOfDay 17 6 0,"cinq heures six de l'apr\232s-midi")
  , (TimeOfDay 17 7 0,"cinq heures sept de l'apr\232s-midi")
  , (TimeOfDay 17 8 0,"cinq heures huit de l'apr\232s-midi")
  , (TimeOfDay 17 9 0,"cinq heures neuf de l'apr\232s-midi")
  , (TimeOfDay 17 10 0,"cinq heures dix de l'apr\232s-midi")
  , (TimeOfDay 17 11 0,"cinq heures onze de l'apr\232s-midi")
  , (TimeOfDay 17 12 0,"cinq heures douze de l'apr\232s-midi")
  , (TimeOfDay 17 13 0,"cinq heures treize de l'apr\232s-midi")
  , (TimeOfDay 17 14 0,"cinq heures quatorze de l'apr\232s-midi")
  , (TimeOfDay 17 15 0,"cinq heures et quart de l'apr\232s-midi")
  , (TimeOfDay 17 16 0,"cinq heures seize de l'apr\232s-midi")
  , (TimeOfDay 17 17 0,"cinq heures dix-sept de l'apr\232s-midi")
  , (TimeOfDay 17 18 0,"cinq heures dix-huit de l'apr\232s-midi")
  , (TimeOfDay 17 19 0,"cinq heures dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 17 20 0,"cinq heures vingt de l'apr\232s-midi")
  , (TimeOfDay 17 21 0,"cinq heures vingt et un de l'apr\232s-midi")
  , (TimeOfDay 17 22 0,"cinq heures vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 17 23 0,"cinq heures vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 17 24 0,"cinq heures vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 17 25 0,"cinq heures vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 17 26 0,"cinq heures vingt-six de l'apr\232s-midi")
  , (TimeOfDay 17 27 0,"cinq heures vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 17 28 0,"cinq heures vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 17 29 0,"cinq heures vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 17 30 0,"cinq heures et demie de l'apr\232s-midi")
  , (TimeOfDay 17 31 0,"six heures moins vingt-neuf de l'apr\232s-midi")
  , (TimeOfDay 17 32 0,"six heures moins vingt-huit de l'apr\232s-midi")
  , (TimeOfDay 17 33 0,"six heures moins vingt-sept de l'apr\232s-midi")
  , (TimeOfDay 17 34 0,"six heures moins vingt-six de l'apr\232s-midi")
  , (TimeOfDay 17 35 0,"six heures moins vingt-cinq de l'apr\232s-midi")
  , (TimeOfDay 17 36 0,"six heures moins vingt-quatre de l'apr\232s-midi")
  , (TimeOfDay 17 37 0,"six heures moins vingt-trois de l'apr\232s-midi")
  , (TimeOfDay 17 38 0,"six heures moins vingt-deux de l'apr\232s-midi")
  , (TimeOfDay 17 39 0,"six heures moins vingt et un de l'apr\232s-midi")
  , (TimeOfDay 17 40 0,"six heures moins vingt de l'apr\232s-midi")
  , (TimeOfDay 17 41 0,"six heures moins dix-neuf de l'apr\232s-midi")
  , (TimeOfDay 17 42 0,"six heures moins dix-huit de l'apr\232s-midi")
  , (TimeOfDay 17 43 0,"six heures moins dix-sept de l'apr\232s-midi")
  , (TimeOfDay 17 44 0,"six heures moins seize de l'apr\232s-midi")
  , (TimeOfDay 17 45 0,"six heures moins le quart de l'apr\232s-midi")
  , (TimeOfDay 17 46 0,"six heures moins quatorze de l'apr\232s-midi")
  , (TimeOfDay 17 47 0,"six heures moins treize de l'apr\232s-midi")
  , (TimeOfDay 17 48 0,"six heures moins douze de l'apr\232s-midi")
  , (TimeOfDay 17 49 0,"six heures moins onze de l'apr\232s-midi")
  , (TimeOfDay 17 50 0,"six heures moins dix de l'apr\232s-midi")
  , (TimeOfDay 17 51 0,"six heures moins neuf de l'apr\232s-midi")
  , (TimeOfDay 17 52 0,"six heures moins huit de l'apr\232s-midi")
  , (TimeOfDay 17 53 0,"six heures moins sept de l'apr\232s-midi")
  , (TimeOfDay 17 54 0,"six heures moins six de l'apr\232s-midi")
  , (TimeOfDay 17 55 0,"six heures moins cinq de l'apr\232s-midi")
  , (TimeOfDay 17 56 0,"six heures moins quatre de l'apr\232s-midi")
  , (TimeOfDay 17 57 0,"six heures moins trois de l'apr\232s-midi")
  , (TimeOfDay 17 58 0,"six heures moins deux de l'apr\232s-midi")
  , (TimeOfDay 17 59 0,"six heures moins un de l'apr\232s-midi")
  , (TimeOfDay 18 0 0,"six heures du soir")
  , (TimeOfDay 18 1 0,"six heures un du soir")
  , (TimeOfDay 18 2 0,"six heures deux du soir")
  , (TimeOfDay 18 3 0,"six heures trois du soir")
  , (TimeOfDay 18 4 0,"six heures quatre du soir")
  , (TimeOfDay 18 5 0,"six heures cinq du soir")
  , (TimeOfDay 18 6 0,"six heures six du soir")
  , (TimeOfDay 18 7 0,"six heures sept du soir")
  , (TimeOfDay 18 8 0,"six heures huit du soir")
  , (TimeOfDay 18 9 0,"six heures neuf du soir")
  , (TimeOfDay 18 10 0,"six heures dix du soir")
  , (TimeOfDay 18 11 0,"six heures onze du soir")
  , (TimeOfDay 18 12 0,"six heures douze du soir")
  , (TimeOfDay 18 13 0,"six heures treize du soir")
  , (TimeOfDay 18 14 0,"six heures quatorze du soir")
  , (TimeOfDay 18 15 0,"six heures et quart du soir")
  , (TimeOfDay 18 16 0,"six heures seize du soir")
  , (TimeOfDay 18 17 0,"six heures dix-sept du soir")
  , (TimeOfDay 18 18 0,"six heures dix-huit du soir")
  , (TimeOfDay 18 19 0,"six heures dix-neuf du soir")
  , (TimeOfDay 18 20 0,"six heures vingt du soir")
  , (TimeOfDay 18 21 0,"six heures vingt et un du soir")
  , (TimeOfDay 18 22 0,"six heures vingt-deux du soir")
  , (TimeOfDay 18 23 0,"six heures vingt-trois du soir")
  , (TimeOfDay 18 24 0,"six heures vingt-quatre du soir")
  , (TimeOfDay 18 25 0,"six heures vingt-cinq du soir")
  , (TimeOfDay 18 26 0,"six heures vingt-six du soir")
  , (TimeOfDay 18 27 0,"six heures vingt-sept du soir")
  , (TimeOfDay 18 28 0,"six heures vingt-huit du soir")
  , (TimeOfDay 18 29 0,"six heures vingt-neuf du soir")
  , (TimeOfDay 18 30 0,"six heures et demie du soir")
  , (TimeOfDay 18 31 0,"sept heures moins vingt-neuf du soir")
  , (TimeOfDay 18 32 0,"sept heures moins vingt-huit du soir")
  , (TimeOfDay 18 33 0,"sept heures moins vingt-sept du soir")
  , (TimeOfDay 18 34 0,"sept heures moins vingt-six du soir")
  , (TimeOfDay 18 35 0,"sept heures moins vingt-cinq du soir")
  , (TimeOfDay 18 36 0,"sept heures moins vingt-quatre du soir")
  , (TimeOfDay 18 37 0,"sept heures moins vingt-trois du soir")
  , (TimeOfDay 18 38 0,"sept heures moins vingt-deux du soir")
  , (TimeOfDay 18 39 0,"sept heures moins vingt et un du soir")
  , (TimeOfDay 18 40 0,"sept heures moins vingt du soir")
  , (TimeOfDay 18 41 0,"sept heures moins dix-neuf du soir")
  , (TimeOfDay 18 42 0,"sept heures moins dix-huit du soir")
  , (TimeOfDay 18 43 0,"sept heures moins dix-sept du soir")
  , (TimeOfDay 18 44 0,"sept heures moins seize du soir")
  , (TimeOfDay 18 45 0,"sept heures moins le quart du soir")
  , (TimeOfDay 18 46 0,"sept heures moins quatorze du soir")
  , (TimeOfDay 18 47 0,"sept heures moins treize du soir")
  , (TimeOfDay 18 48 0,"sept heures moins douze du soir")
  , (TimeOfDay 18 49 0,"sept heures moins onze du soir")
  , (TimeOfDay 18 50 0,"sept heures moins dix du soir")
  , (TimeOfDay 18 51 0,"sept heures moins neuf du soir")
  , (TimeOfDay 18 52 0,"sept heures moins huit du soir")
  , (TimeOfDay 18 53 0,"sept heures moins sept du soir")
  , (TimeOfDay 18 54 0,"sept heures moins six du soir")
  , (TimeOfDay 18 55 0,"sept heures moins cinq du soir")
  , (TimeOfDay 18 56 0,"sept heures moins quatre du soir")
  , (TimeOfDay 18 57 0,"sept heures moins trois du soir")
  , (TimeOfDay 18 58 0,"sept heures moins deux du soir")
  , (TimeOfDay 18 59 0,"sept heures moins un du soir")
  , (TimeOfDay 19 0 0,"sept heures du soir")
  , (TimeOfDay 19 1 0,"sept heures un du soir")
  , (TimeOfDay 19 2 0,"sept heures deux du soir")
  , (TimeOfDay 19 3 0,"sept heures trois du soir")
  , (TimeOfDay 19 4 0,"sept heures quatre du soir")
  , (TimeOfDay 19 5 0,"sept heures cinq du soir")
  , (TimeOfDay 19 6 0,"sept heures six du soir")
  , (TimeOfDay 19 7 0,"sept heures sept du soir")
  , (TimeOfDay 19 8 0,"sept heures huit du soir")
  , (TimeOfDay 19 9 0,"sept heures neuf du soir")
  , (TimeOfDay 19 10 0,"sept heures dix du soir")
  , (TimeOfDay 19 11 0,"sept heures onze du soir")
  , (TimeOfDay 19 12 0,"sept heures douze du soir")
  , (TimeOfDay 19 13 0,"sept heures treize du soir")
  , (TimeOfDay 19 14 0,"sept heures quatorze du soir")
  , (TimeOfDay 19 15 0,"sept heures et quart du soir")
  , (TimeOfDay 19 16 0,"sept heures seize du soir")
  , (TimeOfDay 19 17 0,"sept heures dix-sept du soir")
  , (TimeOfDay 19 18 0,"sept heures dix-huit du soir")
  , (TimeOfDay 19 19 0,"sept heures dix-neuf du soir")
  , (TimeOfDay 19 20 0,"sept heures vingt du soir")
  , (TimeOfDay 19 21 0,"sept heures vingt et un du soir")
  , (TimeOfDay 19 22 0,"sept heures vingt-deux du soir")
  , (TimeOfDay 19 23 0,"sept heures vingt-trois du soir")
  , (TimeOfDay 19 24 0,"sept heures vingt-quatre du soir")
  , (TimeOfDay 19 25 0,"sept heures vingt-cinq du soir")
  , (TimeOfDay 19 26 0,"sept heures vingt-six du soir")
  , (TimeOfDay 19 27 0,"sept heures vingt-sept du soir")
  , (TimeOfDay 19 28 0,"sept heures vingt-huit du soir")
  , (TimeOfDay 19 29 0,"sept heures vingt-neuf du soir")
  , (TimeOfDay 19 30 0,"sept heures et demie du soir")
  , (TimeOfDay 19 31 0,"huit heures moins vingt-neuf du soir")
  , (TimeOfDay 19 32 0,"huit heures moins vingt-huit du soir")
  , (TimeOfDay 19 33 0,"huit heures moins vingt-sept du soir")
  , (TimeOfDay 19 34 0,"huit heures moins vingt-six du soir")
  , (TimeOfDay 19 35 0,"huit heures moins vingt-cinq du soir")
  , (TimeOfDay 19 36 0,"huit heures moins vingt-quatre du soir")
  , (TimeOfDay 19 37 0,"huit heures moins vingt-trois du soir")
  , (TimeOfDay 19 38 0,"huit heures moins vingt-deux du soir")
  , (TimeOfDay 19 39 0,"huit heures moins vingt et un du soir")
  , (TimeOfDay 19 40 0,"huit heures moins vingt du soir")
  , (TimeOfDay 19 41 0,"huit heures moins dix-neuf du soir")
  , (TimeOfDay 19 42 0,"huit heures moins dix-huit du soir")
  , (TimeOfDay 19 43 0,"huit heures moins dix-sept du soir")
  , (TimeOfDay 19 44 0,"huit heures moins seize du soir")
  , (TimeOfDay 19 45 0,"huit heures moins le quart du soir")
  , (TimeOfDay 19 46 0,"huit heures moins quatorze du soir")
  , (TimeOfDay 19 47 0,"huit heures moins treize du soir")
  , (TimeOfDay 19 48 0,"huit heures moins douze du soir")
  , (TimeOfDay 19 49 0,"huit heures moins onze du soir")
  , (TimeOfDay 19 50 0,"huit heures moins dix du soir")
  , (TimeOfDay 19 51 0,"huit heures moins neuf du soir")
  , (TimeOfDay 19 52 0,"huit heures moins huit du soir")
  , (TimeOfDay 19 53 0,"huit heures moins sept du soir")
  , (TimeOfDay 19 54 0,"huit heures moins six du soir")
  , (TimeOfDay 19 55 0,"huit heures moins cinq du soir")
  , (TimeOfDay 19 56 0,"huit heures moins quatre du soir")
  , (TimeOfDay 19 57 0,"huit heures moins trois du soir")
  , (TimeOfDay 19 58 0,"huit heures moins deux du soir")
  , (TimeOfDay 19 59 0,"huit heures moins un du soir")
  , (TimeOfDay 20 0 0,"huit heures du soir")
  , (TimeOfDay 20 1 0,"huit heures un du soir")
  , (TimeOfDay 20 2 0,"huit heures deux du soir")
  , (TimeOfDay 20 3 0,"huit heures trois du soir")
  , (TimeOfDay 20 4 0,"huit heures quatre du soir")
  , (TimeOfDay 20 5 0,"huit heures cinq du soir")
  , (TimeOfDay 20 6 0,"huit heures six du soir")
  , (TimeOfDay 20 7 0,"huit heures sept du soir")
  , (TimeOfDay 20 8 0,"huit heures huit du soir")
  , (TimeOfDay 20 9 0,"huit heures neuf du soir")
  , (TimeOfDay 20 10 0,"huit heures dix du soir")
  , (TimeOfDay 20 11 0,"huit heures onze du soir")
  , (TimeOfDay 20 12 0,"huit heures douze du soir")
  , (TimeOfDay 20 13 0,"huit heures treize du soir")
  , (TimeOfDay 20 14 0,"huit heures quatorze du soir")
  , (TimeOfDay 20 15 0,"huit heures et quart du soir")
  , (TimeOfDay 20 16 0,"huit heures seize du soir")
  , (TimeOfDay 20 17 0,"huit heures dix-sept du soir")
  , (TimeOfDay 20 18 0,"huit heures dix-huit du soir")
  , (TimeOfDay 20 19 0,"huit heures dix-neuf du soir")
  , (TimeOfDay 20 20 0,"huit heures vingt du soir")
  , (TimeOfDay 20 21 0,"huit heures vingt et un du soir")
  , (TimeOfDay 20 22 0,"huit heures vingt-deux du soir")
  , (TimeOfDay 20 23 0,"huit heures vingt-trois du soir")
  , (TimeOfDay 20 24 0,"huit heures vingt-quatre du soir")
  , (TimeOfDay 20 25 0,"huit heures vingt-cinq du soir")
  , (TimeOfDay 20 26 0,"huit heures vingt-six du soir")
  , (TimeOfDay 20 27 0,"huit heures vingt-sept du soir")
  , (TimeOfDay 20 28 0,"huit heures vingt-huit du soir")
  , (TimeOfDay 20 29 0,"huit heures vingt-neuf du soir")
  , (TimeOfDay 20 30 0,"huit heures et demie du soir")
  , (TimeOfDay 20 31 0,"neuf heures moins vingt-neuf du soir")
  , (TimeOfDay 20 32 0,"neuf heures moins vingt-huit du soir")
  , (TimeOfDay 20 33 0,"neuf heures moins vingt-sept du soir")
  , (TimeOfDay 20 34 0,"neuf heures moins vingt-six du soir")
  , (TimeOfDay 20 35 0,"neuf heures moins vingt-cinq du soir")
  , (TimeOfDay 20 36 0,"neuf heures moins vingt-quatre du soir")
  , (TimeOfDay 20 37 0,"neuf heures moins vingt-trois du soir")
  , (TimeOfDay 20 38 0,"neuf heures moins vingt-deux du soir")
  , (TimeOfDay 20 39 0,"neuf heures moins vingt et un du soir")
  , (TimeOfDay 20 40 0,"neuf heures moins vingt du soir")
  , (TimeOfDay 20 41 0,"neuf heures moins dix-neuf du soir")
  , (TimeOfDay 20 42 0,"neuf heures moins dix-huit du soir")
  , (TimeOfDay 20 43 0,"neuf heures moins dix-sept du soir")
  , (TimeOfDay 20 44 0,"neuf heures moins seize du soir")
  , (TimeOfDay 20 45 0,"neuf heures moins le quart du soir")
  , (TimeOfDay 20 46 0,"neuf heures moins quatorze du soir")
  , (TimeOfDay 20 47 0,"neuf heures moins treize du soir")
  , (TimeOfDay 20 48 0,"neuf heures moins douze du soir")
  , (TimeOfDay 20 49 0,"neuf heures moins onze du soir")
  , (TimeOfDay 20 50 0,"neuf heures moins dix du soir")
  , (TimeOfDay 20 51 0,"neuf heures moins neuf du soir")
  , (TimeOfDay 20 52 0,"neuf heures moins huit du soir")
  , (TimeOfDay 20 53 0,"neuf heures moins sept du soir")
  , (TimeOfDay 20 54 0,"neuf heures moins six du soir")
  , (TimeOfDay 20 55 0,"neuf heures moins cinq du soir")
  , (TimeOfDay 20 56 0,"neuf heures moins quatre du soir")
  , (TimeOfDay 20 57 0,"neuf heures moins trois du soir")
  , (TimeOfDay 20 58 0,"neuf heures moins deux du soir")
  , (TimeOfDay 20 59 0,"neuf heures moins un du soir")
  , (TimeOfDay 21 0 0,"neuf heures du soir")
  , (TimeOfDay 21 1 0,"neuf heures un du soir")
  , (TimeOfDay 21 2 0,"neuf heures deux du soir")
  , (TimeOfDay 21 3 0,"neuf heures trois du soir")
  , (TimeOfDay 21 4 0,"neuf heures quatre du soir")
  , (TimeOfDay 21 5 0,"neuf heures cinq du soir")
  , (TimeOfDay 21 6 0,"neuf heures six du soir")
  , (TimeOfDay 21 7 0,"neuf heures sept du soir")
  , (TimeOfDay 21 8 0,"neuf heures huit du soir")
  , (TimeOfDay 21 9 0,"neuf heures neuf du soir")
  , (TimeOfDay 21 10 0,"neuf heures dix du soir")
  , (TimeOfDay 21 11 0,"neuf heures onze du soir")
  , (TimeOfDay 21 12 0,"neuf heures douze du soir")
  , (TimeOfDay 21 13 0,"neuf heures treize du soir")
  , (TimeOfDay 21 14 0,"neuf heures quatorze du soir")
  , (TimeOfDay 21 15 0,"neuf heures et quart du soir")
  , (TimeOfDay 21 16 0,"neuf heures seize du soir")
  , (TimeOfDay 21 17 0,"neuf heures dix-sept du soir")
  , (TimeOfDay 21 18 0,"neuf heures dix-huit du soir")
  , (TimeOfDay 21 19 0,"neuf heures dix-neuf du soir")
  , (TimeOfDay 21 20 0,"neuf heures vingt du soir")
  , (TimeOfDay 21 21 0,"neuf heures vingt et un du soir")
  , (TimeOfDay 21 22 0,"neuf heures vingt-deux du soir")
  , (TimeOfDay 21 23 0,"neuf heures vingt-trois du soir")
  , (TimeOfDay 21 24 0,"neuf heures vingt-quatre du soir")
  , (TimeOfDay 21 25 0,"neuf heures vingt-cinq du soir")
  , (TimeOfDay 21 26 0,"neuf heures vingt-six du soir")
  , (TimeOfDay 21 27 0,"neuf heures vingt-sept du soir")
  , (TimeOfDay 21 28 0,"neuf heures vingt-huit du soir")
  , (TimeOfDay 21 29 0,"neuf heures vingt-neuf du soir")
  , (TimeOfDay 21 30 0,"neuf heures et demie du soir")
  , (TimeOfDay 21 31 0,"dix heures moins vingt-neuf du soir")
  , (TimeOfDay 21 32 0,"dix heures moins vingt-huit du soir")
  , (TimeOfDay 21 33 0,"dix heures moins vingt-sept du soir")
  , (TimeOfDay 21 34 0,"dix heures moins vingt-six du soir")
  , (TimeOfDay 21 35 0,"dix heures moins vingt-cinq du soir")
  , (TimeOfDay 21 36 0,"dix heures moins vingt-quatre du soir")
  , (TimeOfDay 21 37 0,"dix heures moins vingt-trois du soir")
  , (TimeOfDay 21 38 0,"dix heures moins vingt-deux du soir")
  , (TimeOfDay 21 39 0,"dix heures moins vingt et un du soir")
  , (TimeOfDay 21 40 0,"dix heures moins vingt du soir")
  , (TimeOfDay 21 41 0,"dix heures moins dix-neuf du soir")
  , (TimeOfDay 21 42 0,"dix heures moins dix-huit du soir")
  , (TimeOfDay 21 43 0,"dix heures moins dix-sept du soir")
  , (TimeOfDay 21 44 0,"dix heures moins seize du soir")
  , (TimeOfDay 21 45 0,"dix heures moins le quart du soir")
  , (TimeOfDay 21 46 0,"dix heures moins quatorze du soir")
  , (TimeOfDay 21 47 0,"dix heures moins treize du soir")
  , (TimeOfDay 21 48 0,"dix heures moins douze du soir")
  , (TimeOfDay 21 49 0,"dix heures moins onze du soir")
  , (TimeOfDay 21 50 0,"dix heures moins dix du soir")
  , (TimeOfDay 21 51 0,"dix heures moins neuf du soir")
  , (TimeOfDay 21 52 0,"dix heures moins huit du soir")
  , (TimeOfDay 21 53 0,"dix heures moins sept du soir")
  , (TimeOfDay 21 54 0,"dix heures moins six du soir")
  , (TimeOfDay 21 55 0,"dix heures moins cinq du soir")
  , (TimeOfDay 21 56 0,"dix heures moins quatre du soir")
  , (TimeOfDay 21 57 0,"dix heures moins trois du soir")
  , (TimeOfDay 21 58 0,"dix heures moins deux du soir")
  , (TimeOfDay 21 59 0,"dix heures moins un du soir")
  , (TimeOfDay 22 0 0,"dix heures du soir")
  , (TimeOfDay 22 1 0,"dix heures un du soir")
  , (TimeOfDay 22 2 0,"dix heures deux du soir")
  , (TimeOfDay 22 3 0,"dix heures trois du soir")
  , (TimeOfDay 22 4 0,"dix heures quatre du soir")
  , (TimeOfDay 22 5 0,"dix heures cinq du soir")
  , (TimeOfDay 22 6 0,"dix heures six du soir")
  , (TimeOfDay 22 7 0,"dix heures sept du soir")
  , (TimeOfDay 22 8 0,"dix heures huit du soir")
  , (TimeOfDay 22 9 0,"dix heures neuf du soir")
  , (TimeOfDay 22 10 0,"dix heures dix du soir")
  , (TimeOfDay 22 11 0,"dix heures onze du soir")
  , (TimeOfDay 22 12 0,"dix heures douze du soir")
  , (TimeOfDay 22 13 0,"dix heures treize du soir")
  , (TimeOfDay 22 14 0,"dix heures quatorze du soir")
  , (TimeOfDay 22 15 0,"dix heures et quart du soir")
  , (TimeOfDay 22 16 0,"dix heures seize du soir")
  , (TimeOfDay 22 17 0,"dix heures dix-sept du soir")
  , (TimeOfDay 22 18 0,"dix heures dix-huit du soir")
  , (TimeOfDay 22 19 0,"dix heures dix-neuf du soir")
  , (TimeOfDay 22 20 0,"dix heures vingt du soir")
  , (TimeOfDay 22 21 0,"dix heures vingt et un du soir")
  , (TimeOfDay 22 22 0,"dix heures vingt-deux du soir")
  , (TimeOfDay 22 23 0,"dix heures vingt-trois du soir")
  , (TimeOfDay 22 24 0,"dix heures vingt-quatre du soir")
  , (TimeOfDay 22 25 0,"dix heures vingt-cinq du soir")
  , (TimeOfDay 22 26 0,"dix heures vingt-six du soir")
  , (TimeOfDay 22 27 0,"dix heures vingt-sept du soir")
  , (TimeOfDay 22 28 0,"dix heures vingt-huit du soir")
  , (TimeOfDay 22 29 0,"dix heures vingt-neuf du soir")
  , (TimeOfDay 22 30 0,"dix heures et demie du soir")
  , (TimeOfDay 22 31 0,"onze heures moins vingt-neuf du soir")
  , (TimeOfDay 22 32 0,"onze heures moins vingt-huit du soir")
  , (TimeOfDay 22 33 0,"onze heures moins vingt-sept du soir")
  , (TimeOfDay 22 34 0,"onze heures moins vingt-six du soir")
  , (TimeOfDay 22 35 0,"onze heures moins vingt-cinq du soir")
  , (TimeOfDay 22 36 0,"onze heures moins vingt-quatre du soir")
  , (TimeOfDay 22 37 0,"onze heures moins vingt-trois du soir")
  , (TimeOfDay 22 38 0,"onze heures moins vingt-deux du soir")
  , (TimeOfDay 22 39 0,"onze heures moins vingt et un du soir")
  , (TimeOfDay 22 40 0,"onze heures moins vingt du soir")
  , (TimeOfDay 22 41 0,"onze heures moins dix-neuf du soir")
  , (TimeOfDay 22 42 0,"onze heures moins dix-huit du soir")
  , (TimeOfDay 22 43 0,"onze heures moins dix-sept du soir")
  , (TimeOfDay 22 44 0,"onze heures moins seize du soir")
  , (TimeOfDay 22 45 0,"onze heures moins le quart du soir")
  , (TimeOfDay 22 46 0,"onze heures moins quatorze du soir")
  , (TimeOfDay 22 47 0,"onze heures moins treize du soir")
  , (TimeOfDay 22 48 0,"onze heures moins douze du soir")
  , (TimeOfDay 22 49 0,"onze heures moins onze du soir")
  , (TimeOfDay 22 50 0,"onze heures moins dix du soir")
  , (TimeOfDay 22 51 0,"onze heures moins neuf du soir")
  , (TimeOfDay 22 52 0,"onze heures moins huit du soir")
  , (TimeOfDay 22 53 0,"onze heures moins sept du soir")
  , (TimeOfDay 22 54 0,"onze heures moins six du soir")
  , (TimeOfDay 22 55 0,"onze heures moins cinq du soir")
  , (TimeOfDay 22 56 0,"onze heures moins quatre du soir")
  , (TimeOfDay 22 57 0,"onze heures moins trois du soir")
  , (TimeOfDay 22 58 0,"onze heures moins deux du soir")
  , (TimeOfDay 22 59 0,"onze heures moins un du soir")
  , (TimeOfDay 23 0 0,"onze heures du soir")
  , (TimeOfDay 23 1 0,"onze heures un du soir")
  , (TimeOfDay 23 2 0,"onze heures deux du soir")
  , (TimeOfDay 23 3 0,"onze heures trois du soir")
  , (TimeOfDay 23 4 0,"onze heures quatre du soir")
  , (TimeOfDay 23 5 0,"onze heures cinq du soir")
  , (TimeOfDay 23 6 0,"onze heures six du soir")
  , (TimeOfDay 23 7 0,"onze heures sept du soir")
  , (TimeOfDay 23 8 0,"onze heures huit du soir")
  , (TimeOfDay 23 9 0,"onze heures neuf du soir")
  , (TimeOfDay 23 10 0,"onze heures dix du soir")
  , (TimeOfDay 23 11 0,"onze heures onze du soir")
  , (TimeOfDay 23 12 0,"onze heures douze du soir")
  , (TimeOfDay 23 13 0,"onze heures treize du soir")
  , (TimeOfDay 23 14 0,"onze heures quatorze du soir")
  , (TimeOfDay 23 15 0,"onze heures et quart du soir")
  , (TimeOfDay 23 16 0,"onze heures seize du soir")
  , (TimeOfDay 23 17 0,"onze heures dix-sept du soir")
  , (TimeOfDay 23 18 0,"onze heures dix-huit du soir")
  , (TimeOfDay 23 19 0,"onze heures dix-neuf du soir")
  , (TimeOfDay 23 20 0,"onze heures vingt du soir")
  , (TimeOfDay 23 21 0,"onze heures vingt et un du soir")
  , (TimeOfDay 23 22 0,"onze heures vingt-deux du soir")
  , (TimeOfDay 23 23 0,"onze heures vingt-trois du soir")
  , (TimeOfDay 23 24 0,"onze heures vingt-quatre du soir")
  , (TimeOfDay 23 25 0,"onze heures vingt-cinq du soir")
  , (TimeOfDay 23 26 0,"onze heures vingt-six du soir")
  , (TimeOfDay 23 27 0,"onze heures vingt-sept du soir")
  , (TimeOfDay 23 28 0,"onze heures vingt-huit du soir")
  , (TimeOfDay 23 29 0,"onze heures vingt-neuf du soir")
  , (TimeOfDay 23 30 0,"onze heures et demie du soir")
  , (TimeOfDay 23 31 0,"douze heures moins vingt-neuf du soir")
  , (TimeOfDay 23 32 0,"douze heures moins vingt-huit du soir")
  , (TimeOfDay 23 33 0,"douze heures moins vingt-sept du soir")
  , (TimeOfDay 23 34 0,"douze heures moins vingt-six du soir")
  , (TimeOfDay 23 35 0,"douze heures moins vingt-cinq du soir")
  , (TimeOfDay 23 36 0,"douze heures moins vingt-quatre du soir")
  , (TimeOfDay 23 37 0,"douze heures moins vingt-trois du soir")
  , (TimeOfDay 23 38 0,"douze heures moins vingt-deux du soir")
  , (TimeOfDay 23 39 0,"douze heures moins vingt et un du soir")
  , (TimeOfDay 23 40 0,"douze heures moins vingt du soir")
  , (TimeOfDay 23 41 0,"douze heures moins dix-neuf du soir")
  , (TimeOfDay 23 42 0,"douze heures moins dix-huit du soir")
  , (TimeOfDay 23 43 0,"douze heures moins dix-sept du soir")
  , (TimeOfDay 23 44 0,"douze heures moins seize du soir")
  , (TimeOfDay 23 45 0,"douze heures moins le quart du soir")
  , (TimeOfDay 23 46 0,"douze heures moins quatorze du soir")
  , (TimeOfDay 23 47 0,"douze heures moins treize du soir")
  , (TimeOfDay 23 48 0,"douze heures moins douze du soir")
  , (TimeOfDay 23 49 0,"douze heures moins onze du soir")
  , (TimeOfDay 23 50 0,"douze heures moins dix du soir")
  , (TimeOfDay 23 51 0,"douze heures moins neuf du soir")
  , (TimeOfDay 23 52 0,"douze heures moins huit du soir")
  , (TimeOfDay 23 53 0,"douze heures moins sept du soir")
  , (TimeOfDay 23 54 0,"douze heures moins six du soir")
  , (TimeOfDay 23 55 0,"douze heures moins cinq du soir")
  , (TimeOfDay 23 56 0,"douze heures moins quatre du soir")
  , (TimeOfDay 23 57 0,"douze heures moins trois du soir")
  , (TimeOfDay 23 58 0,"douze heures moins deux du soir")
  , (TimeOfDay 23 59 0,"douze heures moins un du soir")
  ]
